* Creates plot of ugap series, with shading above threshold of 1.95.
* Add inflation
********************************************************************************
clear all
set more off
set matsize 800

// requires installing bgshade command
*ssc install bgshade

use "../data/AggregatePC.dta", clear

gen above = u_gap>1.95 // ugap above the threshold // 0.24 for gdp

* compute inflation minus expectations
// Ball and Mazumder
gen infl_minus_exp = infl_cpi - (L.infl_cpi + L2.infl_cpi + L3.infl_cpi + L4.infl_cpi)/4
gen infl_minus_exp_MI = infl_cpi - exp_infl_MI 
gen infl_minus_exp_SPF = infl_cpi - exp_infl_SPF_gdp

* Take 4 qtrs MA (for visibility): similar to YoY
tssmooth ma infl_minus_exp_ma = infl_minus_exp, window(3 1 0 ) 

* define the sample period
keep if quarter>=tq(1968q4) & quarter<=tq(2019q4)

foreach vv of var infl_minus_exp infl_minus_exp_MI infl_minus_exp_SPF {
replace `vv'=. if `vv'<-10 // drop the outlier in 2009:Q4
}

* assign plot labels
lab def dates `=tq(1970q1)' "1970", add
lab def dates `=tq(1975q1)' "1975", add
lab def dates `=tq(1980q1)' "1980", add
lab def dates `=tq(1985q1)' "1985", add
lab def dates `=tq(1990q1)' "1990", add
lab def dates `=tq(1995q1)' "1995", add
lab def dates `=tq(2000q1)' "2000", add
lab def dates `=tq(2005q1)' "2005", add
lab def dates `=tq(2010q1)' "2010", add
lab def dates `=tq(2015q1)' "2015", add
lab def dates `=tq(2020q1)' "2020", add

lab val quarter dates


* new graph: version 5: Inflation and unemployment (headline)
bgshade quarter, shaders(above) sstyle(lc(gs13) lw(1.45)) /// 
twoway ///
	(tsline u_gap, yaxis(1) lw(1.25) lcolor(black)  lp(solid)  ///
 ylabel(-3(1)5, axis(1) grid tp(i) angle(h) labsize(huge)) ysc(r(-3,5) axis(1)) ///
 || tsline infl_cpi, yaxis(2) lw(.75) lcolor( maroon%50)  lp(longdash_dot) ///
yline(1.95, lc(black) lw(0.5)) /// title("Unemployment gap relative to threshold", size(medlarge)) 
 ylabel(-12(4)20, axis(2) tp(i) tlc(maroon%80) labc(maroon%80)  angle(h) labsize(huge)) ysc(r(-12,20) lc(maroon%80) axis(2)) ///
ttitle("", size(huge)) yti("") ytitle("",axis(2)) ///
legend(order(1 "{&larr} Unemployment gap, %" 2 "{&rarr} CPI inflation, %") textfirst colgap(1.3in) size(huge) col(2) pos(12) ring(1) region(style(none))) ///
tlabel(1970q1(20)2020q1, tp(i) labsize(huge) valuelabel) tmti(1968q1(4)2020q1, tp(i)) xsc(r(`=tq(1968q1)',`=tq(2021q1)')) ///
/// subtitle("%",  size(huge) ring(1) pos(11)) ///
text(1.95 `=tq(2000q1)' "Threshold = 1.95%", place(n) size(huge)) name(g1) ///
scheme(s1color) plotregion(sty(none) margin(zero)) graphregion(margin(medsmall)) ) 
 
graph display, ysize(2) xsize(6.5)
graph export "../figures/Figure1.pdf", replace as(pdf)  fontface("Georgia")	
