/*
	- Creates figures B4 and table B9
*/


clear all
set more off, perm
set matsize 10000
set logtype tex
set linesize 150

loc do_dir subroutines
use "../data/AggregatePC.dta", clear

loc number_lags 5 //in quarters

* create lags
foreach var of var infl* P_fdEnrgy_chng exp_infl_MI {
	forv ll = 0/`number_lags' {
		g l`ll'_`var' = l`ll'.`var'
	}
}

* create 'explained' expectations, controlling for lags and volatile prices
reg exp_infl_MI l1_exp_infl_MI-l4_exp_infl_MI l1_inflcpi_rt - l4_inflcpi_rt L1.ffr L.exp_infl_SPF_gdp d_oil

* create 1 step ahead and dynamic fcasts of MI w/ and w/o oil
predict MI_hat, xb 
la var MI_hat "1 step, w/ oil"

la var MI_hat "Explained portion of MI expectations"

*** Compute forecasts and create figures

forval spec=2/2 {
* define the unemployment variable (u_rate in Spec1, u_gap in Spec2)
if `spec'==1 {
	loc measure = "u_rate"
}
else if `spec'==2 {
	loc measure = "u_gap"
	gen l1_`measure' = L1.u_gap
}
else if `spec'==3 {
	loc measure = "labor_share"
	gen l1_`measure' = L1.labor_share
}
else if `spec'==4 {
	loc measure = "labor_share_alt"
	gen l1_`measure' = L1.labor_share_alt
}
* Store general controls, piecewise controls & backward-looking exp terms (lags)
foreach var of var infl* { // PCE and CPI core
	loc `var'_controls "l1_P_fdEnrgy_chng - l2_P_fdEnrgy_chng gordon"
	qui ds `measure' 
	loc `var'_pcsws_ctrls "`r(varlist)'"
	loc `var'_backexp "l1_`var' - l5_`var'"
}


* define threshold variable: contemp. for PCE and CPI, first lag for GDP deflator

loc Uthresh_infl_pce_core  `measure'
loc Uthresh_infl_pce `measure'
loc Uthresh_infl_cpi_core  `measure'
loc Uthresh_infl_cpi  `measure'
loc Uthresh_infl_gdp  `measure'

* expectation measures to use:
loc fwdexp exp_infl_MI exp_infl_SPF_gdp
loc fwdexp2 MI_hat exp_infl_SPF_gdp 


	foreach var of var infl_pce infl_gdp {
		* MI, SPF GDP & backward looking exp
		loc expvars = "`fwdexp'" + " " + "``var'_backexp'"
		loc expvars_2 = "`fwdexp2'" + " " + "``var'_backexp'"
		

		// Great Inflation
		loc start_date `=tq(1976q2)'
		preserve
		do "`do_dir'/estFigB4_TableB9.do" `var' `Uthresh_`var'' "``var'_pcsws_ctrls'" "``var'_controls'" "`expvars'" "`expvars_2'" `start_date' "`folder_dir'"

		// Save forecast estimates for table 4
		scalar d1_`var' = d1_chg_`var'
		scalar d1_linest_`var' =d1_chg_lin_dyn_`var'_mihat
		scalar d1_linmsc_`var' =d1_chg_lin_dyn_`var'_mispf
		scalar d1_test_`var' =d1_chg__1thr_dyn_`var'_mihat
		scalar d1_tmsc_`var' =d1_chg__1thr_dyn_`var'_mispf		
		
		scalar rmse1_linest_`var' =rmse1_residsq_lin_dyn_mihat
		scalar rmse1_linmsc_`var' =rmse1_residsq_lin_dyn_mispf
		scalar rmse1_test_`var' =rmse1_residsq_dyn_mihat
		scalar rmse1_tmsc_`var' =rmse1_residsq_dyn_mispf		
		
		restore
		
	
		// Volcker Disinflation
		loc start_date `=tq(1979q4)'
		preserve
		do "`do_dir'/estFigB4_TableB9.do" `var' `Uthresh_`var'' "``var'_pcsws_ctrls'" "``var'_controls'" "`expvars'" "`expvars_2'" `start_date' "`folder_dir'"

		scalar d2_`var' = d2_chg_`var'
		scalar d2_linest_`var' =d2_chg_lin_dyn_`var'_mihat
		scalar d2_linmsc_`var' =d2_chg_lin_dyn_`var'_mispf
		scalar d2_test_`var' =d2_chg__1thr_dyn_`var'_mihat
		scalar d2_tmsc_`var' =d2_chg__1thr_dyn_`var'_mispf		

		scalar rmse2_linest_`var' =rmse2_residsq_lin_dyn_mihat
		scalar rmse2_linmsc_`var' =rmse2_residsq_lin_dyn_mispf
		scalar rmse2_test_`var' =rmse2_residsq_dyn_mihat
		scalar rmse2_tmsc_`var' =rmse2_residsq_dyn_mispf			
		restore	
	
		// RMSE for Missing disinflation
		loc start_date `=tq(2007q4)'
		preserve
		do "`do_dir'/estFigB4_TableB9.do" `var' `Uthresh_`var'' "``var'_pcsws_ctrls'" "``var'_controls'" "`expvars'" "`expvars_2'" `start_date' "`folder_dir'"

		scalar rmse3_linest_`var' =rmse3_residsq_lin_dyn_mihat
		scalar rmse3_linmsc_`var' =rmse3_residsq_lin_dyn_mispf
		scalar rmse3_test_`var' =rmse3_residsq_dyn_mihat
		scalar rmse3_tmsc_`var' =rmse3_residsq_dyn_mispf			
		restore	
	}
	
}


* Generate table B9
qui {

log using "../tables/tableB9.tex", tex replace

n di "\begin{tabular}{c*{6}c@{}} \toprule "
n di "& \multicolumn{2}{c}{Great Inflation} & \multicolumn{2}{c}{Volcker Disinflation} & \multicolumn{1}{c}{Missing Disinflation} \\"
n di "\cline{2-3}\cline{4-5}\cline{6-6}"
n di "&  \multicolumn{1}{c}{Peak-to-Trough} & & \multicolumn{1}{c}{Peak-to-Trough} & & \\"
n di "Inflation &  \multicolumn{1}{c}{Change, p.p.} & RMSE & \multicolumn{1}{c}{Change, p.p.} & RMSE & RMSE \\"
n di "& \multicolumn{1}{c}{(1)} & \multicolumn{1}{c}{(2)} & \multicolumn{1}{c}{(3)} & \multicolumn{1}{c}{(4)} & \multicolumn{1}{c}{(5)}\\" 

n di "\hline"

n di "\multicolumn{6}{c}{\textit{Panel A: PCE}} \\"

n di %13s "PCE Inflation & "  /// 
	%5.1f d1_infl_pce " & & "  ///
	%5.1f d2_infl_pce " & & \\ "

n di "\textit{Linear Model} \\"

n di %13s "\hspace{1em} estimated UMSC expectations & "  /// 
	%5.1f d1_linest_infl_pce " & "  ///
	%5.2f rmse1_linest_infl_pce " & " ///
	%5.1f d2_linest_infl_pce " & " ///
	%5.2f rmse2_linest_infl_pce " & " ///
	%5.2f rmse3_linest_infl_pce " \\ "	
	
n di %13s "\hspace{1em} actual expectations & "  /// 
	%5.1f d1_linmsc_infl_pce " & "  ///
	%5.2f rmse1_linmsc_infl_pce " & " ///
	%5.1f d2_linmsc_infl_pce " & " ///
	%5.2f rmse2_linmsc_infl_pce " & " ///
	%5.2f rmse3_linmsc_infl_pce " \\ "
	
n di "\textit{Threshold Model} \\"

n di %13s "\hspace{1em} estimated & "  /// 
	%5.1f d1_test_infl_pce " & "  ///
	%5.2f rmse1_test_infl_pce " & " ///
	%5.1f d2_test_infl_pce " & " ///
	%5.2f rmse2_test_infl_pce " & " ///
	%5.2f rmse3_test_infl_pce " \\ "	
	
n di %13s "\hspace{1em} actual & "  /// 
	%5.1f d1_tmsc_infl_pce " & "  ///
	%5.2f rmse1_tmsc_infl_pce " & " ///
	%5.1f d2_tmsc_infl_pce " & " ///
	%5.2f rmse2_tmsc_infl_pce " & " ///
	%5.2f rmse3_tmsc_infl_pce " \\ "

n di "\midrule"

n di "\multicolumn{6}{c}{\textit{Panel B: GDP Deflator}} \\"

n di %13s "GDP Inflation & "  /// 
	%5.1f d1_infl_gdp " & & "  ///
	%5.1f d2_infl_gdp " & & \\ "

n di "\textit{Linear Model} \\"

n di %13s "\hspace{1em} estimated UMSC expectations & "  /// 
	%5.1f d1_linest_infl_gdp " & "  ///
	%5.2f rmse1_linest_infl_gdp " & " ///
	%5.1f d2_linest_infl_gdp " & " ///
	%5.2f rmse2_linest_infl_gdp " & " ///
	%5.2f rmse3_linest_infl_gdp " \\ "	
	
n di %13s "\hspace{1em} actual expectations & "  /// 
	%5.1f d1_linmsc_infl_gdp " & "  ///
	%5.2f rmse1_linmsc_infl_gdp " & " ///
	%5.1f d2_linmsc_infl_gdp " & " ///
	%5.2f rmse2_linmsc_infl_gdp " & " ///
	%5.2f rmse3_linmsc_infl_gdp " \\ "
	
n di "\textit{Threshold Model} \\"

n di %13s "\hspace{1em} estimated & "  /// 
	%5.1f d1_test_infl_gdp " & "  ///
	%5.2f rmse1_test_infl_gdp " & " ///
	%5.1f d2_test_infl_gdp " & " ///
	%5.2f rmse2_test_infl_gdp " & " ///
	%5.2f rmse3_test_infl_gdp " \\ "	
	
n di %13s "\hspace{1em} actual & "  /// 
	%5.1f d1_tmsc_infl_gdp " & "  ///
	%5.2f rmse1_tmsc_infl_gdp " & " ///
	%5.1f d2_tmsc_infl_gdp " & " ///
	%5.2f rmse2_tmsc_infl_gdp " & " ///
	%5.2f rmse3_tmsc_infl_gdp " \\ "
	
n di"\bottomrule" 
n di "\end{tabular}"
log cl
}
