/*
	Collections estimation results for main section - nonlinearities with 
	consumer expectations.
	
	Recreates estimates except for p-values.
*/

clear all
set more off, perm
cap log close
set logtype tex
set linesize 150

// Define esttab options
#delimit ;
glob regopts = "cells(b(star fmt(2)) se(par fmt(2))) star( * 0.1 ** 0.05 *** 0.01)
collabels(none)  obslast nonumber nonotes nogaps booktabs fragment";
#delimit cr

loc ph_general `" "\begin{tabular}{c*{@span}c@{}}" \toprule  "'
loc pf_general `" "\bottomrule" \end{tabular} "'

loc do_dir subroutines
use "../data/AggregatePC.dta", clear



* create lags
foreach var of var infl* P_fdEnrgy_chng neer_dollar_chng {
	forv ll = 0/5 {
		g l`ll'_`var' = l`ll'.`var'
	}
}
foreach measure in u_gap { 

* Store general controls, piecewise controls & backward-looking exp terms (lags)
foreach var of var infl*core infl_pce infl_cpi infl_gdp infl_cpi_cm { // PCE and CPI core
	loc `var'_controls "l1_P_fdEnrgy_chng - l2_P_fdEnrgy_chng l1_neer_dollar_chng - l2_neer_dollar_chng gordon"
	qui ds `measure' 
	loc `var'_pcsws_ctrls "`r(varlist)'"
	loc `var'_backexp "l1_`var' - l5_`var'"
}


loc Uthresh_infl_pce_core  `measure'
loc Uthresh_infl_pce  `measure'
loc Uthresh_infl_cpi_core  `measure'
loc Uthresh_infl_cpi  `measure'
loc Uthresh_infl_gdp  `measure'
loc Uthresh_infl_cpi_cm  `measure'



loc fwdexp  exp_infl_MI  exp_infl_SPF_gdp

local sample_count 1

keep if exp_infl_SPF_gdp!=.
	foreach var of var infl_cpi infl_pce infl_pce_core infl_cpi_core infl_gdp infl_cpi_cm {

		* MI, SPF GDP & backward looking exp
		if "`var'"=="infl_cpi" loc expvars = "exp_infl_SPF_gdp" + " " +  "``var'_backexp'" //column 1 of table runs without Michigan expectations
		else loc expvars = "`fwdexp'" + " " + "``var'_backexp'" //rest of columns use Michigan expectations to contrast results
		
		preserve
		do "`do_dir'/estimationTables_2v1" `var' `Uthresh_`var'' "``var'_pcsws_ctrls'" "``var'_controls'" "`expvars'" Y

		* store stats
		scalar pval_`var' = pval
		restore

	}
	
}


* output to tex:
*2v1 p-value
qui {
log using "../tables/table2_2v1.tex", tex replace

n di %13s "& \multicolumn{1}{c}{PCE} & \multicolumn{1}{c}{GDP Deflator} & \multicolumn{1}{c}{Core CPI} & \multicolumn{1}{c}{Core PCE}\\"		
n di "\emph{No. of thresholds, $\ p$-val.} \\"

n di %13s "\hspace{1em}1 vs.\ 2, $\ H_0$: 1 & " ///
	%5.2f pval_infl_cpi " & "  ///
	%5.2f pval_infl_pce " & "  ///
	%5.2f pval_infl_gdp " & " ///
	%5.2f pval_infl_cpi_core " & " ///
	%5.2f pval_infl_pce_core " &" ///
	%5.2f pval_infl_cpi_cm " \\" 
	
log cl
}
