// Table 3, col. 3
loc isCIsig 1 // toggle 1/0 to obtain confidence intervals/significance for threshold (slow)

clear all
set more off, perm

// Requires ereplace, carryforward
* ssc install ereplace
* ssc install carryforward

// Define esttab options
#delimit ;
glob regopts = "cells(b(star fmt(2)) se(par fmt(2))) star( * 0.1 ** 0.05 *** 0.01)
collabels(none) nomti obslast nonumber nonotes nogaps booktabs fragment";
#delimit cr

loc ph_general `" "\begin{tabular}{c*{@span}c@{}}" \toprule  "'
loc pf_general `" "\bottomrule" \end{tabular} "'

loc do_dir subroutines
use "../data/RegionalPC.dta", clear
keep if tin(1991h1, 2017h2) & ~inlist(area,2,18,21,26,29) // balanced sample


g year = year(dofh(halfyear))
g half = halfyear(dofh(halfyear))


loc var infl_cpi_core

*create lag
gen l_infl_cpicore = L.infl_cpi_core

* Store controls
loc controls l_infl_cpicore
loc factors i.year i.half
loc pcsws_ctrls u_rate

* expectation measures to use:
loc fwdexp exp_infl_MI

* Transformation: 1 - account for FEs; 2- pool
scalar transform = 1

    // p-value requested?
    if `isCIsig' loc CIsig Y
    else loc CIsig N

do "`do_dir'/estTable3_col3" `var' u_rate "`pcsws_ctrls'" "`controls'" "`factors'" "`fwdexp'" 1 2 `CIsig' transform

loc nameList1 u_rate thresh
loc nameList2 u_rate_left thresh_left u_rate_right thresh_right

scalar t_hat_`var'_ = gstar_`var'_2 + 5.7
scalar nobs_`var'_ = nobs


if `isCIsig' scalar pval_u_rate = pval
else scalar pval_u_rate = -999

* output to tex:
// Linear estimates
esttab lintemp ///
	using "../tables/table3_col3.tex", rename(`nameList1') keep(thresh exp*) nomti $regopts replace ///
	noobs coeflabel(exp_infl_MI "UMSC, $\hat{\alpha}_2$" exp_infl_SPF_gdp_cns "SPF, $\hat{\alpha}_1$" thresh "Slope, $\hat{\beta}$") ///
	prehead(`ph_general' "& \multicolumn{1}{c}{Unemployment}\\" ///
	"& \multicolumn{1}{c}{Rate} \\" ///
	"& \multicolumn{1}{c}{(1)}\\" ///
	"\hline \multicolumn{2}{c}{\textit{Panel A: Linear Model}}\\"  ) posthead("")
	
// Slope estimates, threshold model
esttab t_temp ///
	using "../tables/table3_col3.tex", rename(`nameList2') keep(thresh*) $regopts noobs nomti append ///
	coeflabel(thresh_left "left, $\hat{\beta}_L$" thresh_right "right, $\hat{\beta}_R$") substitute("\_" "_") ///
	prehead("\hline \multicolumn{2}{c}{\textit{Panel B: Threshold Model}}\\" " \textit{Slopes} \\") posthead("")

// Expectations, threshold model
esttab t_temp ///
	using "../tables/table3_col3.tex", rename(`nameList2') keep(exp* l_*) $regopts noobs nomti append ///
	coeflabel(exp_infl_MI "UMSC, $\hat{\alpha}_2$" l_infl_cpicore "Sum of Lags, $\hat{\alpha}_0$") substitute("\_" "_")  ///
	prehead(" \textit{Expected Inflation} \\") posthead("")

// other stats, threshold model
qui {
log using "../tables/table3_col3.tex", tex append

n di "\emph{Threshold}, $\hat{\gamma}$  \\"
 n di %13s "\hspace{1em}point estimate & "  /// 
	%5.2f t_hat_infl_cpi_core_ " \\" 
	
 // uncomment if getting pvalue		
	n di "\emph{No. of thresholds, $\ p$-val.} \\"

	 n di %13s "\hspace{1em}0 vs.\ 1, $\ H_0$: 0 & " ///
		%5.2f pval_u_rate " \\" 

	
 n di %13s "$\ N$ & "  /// 
	%5.0fc nobs_infl_cpi_core_ " \\" 	

n di"\bottomrule" 
n di "\end{tabular}"
log cl
}
