// Table 3 in the paper
// Note: in the paper a slightly different vintage of the dataset was used,
  // which gave rise to immaterial discrepancies.
version 15

clear all
set more off, perm
eststo clear

// Requires newey2
*ssc install newey2

// Define esttab options
#delimit ;
glob regopts = "cells(b(star fmt(2)) se(par fmt(2))) star( * 0.1 ** 0.05 *** 0.01)
collabels(none)  obslast nonumber nonotes nogaps booktabs fragment";
#delimit cr

loc ph_general `" "\begin{tabular}{c*{@span}c@{}}" \toprule  "'
loc pf_general `" "\bottomrule" \end{tabular} "'


loc do_dir subroutines

use "../data/AggregatePC.dta", clear

	
* create lags
foreach var of var infl* P_fdEnrgy_chng neer_dollar_chng {
	forv ll = 0/5 {
		g l`ll'_`var' = l`ll'.`var'
	}
}



* Store general controls, piecewise controls & backward-looking exp terms (lags)
foreach var of var infl_cpi  { 
	loc `var'_controls "l1_P_fdEnrgy_chng - l2_P_fdEnrgy_chng l1_neer_dollar_chng - l2_neer_dollar_chng gordon"
	qui ds u_gap 
	loc `var'_pcsws_ctrls "`r(varlist)'"
	loc `var'_backexp "l1_`var' - l5_`var'"
}


* define threshold variable: contemp. for PCE and CPI, first lag for GDP deflator
loc Uthresh_infl_cpi  u_gap

* expectation measures to use:
loc fwdexp  exp_infl_MI exp_infl_SPF_gdp  



local sample_count 1

foreach instrspec in spliced WuXia {
keep if exp_infl_SPF_gdp!=.
foreach sample in  "1"   {
	*foreach fexp in `fwdexp' {
		foreach var of var infl_cpi {
			
			* MI, SPF GDP & backward looking exp
			loc expvars = "`fwdexp'" + " " + "``var'_backexp'"

			preserve
			do "`do_dir'/estTable3_cols1_2.do" `var' `Uthresh_`var'' "``var'_pcsws_ctrls'" "``var'_controls'" "`expvars'" "`sample'" "`instrspec'" 2 N
			restore

			loc nameList1 `nameList1' `Uthresh_`var'' thresh
			loc nameList2 `nameList2' `Uthresh_`var''_left_cns thresh_left `Uthresh_`var''_right_cns thresh_right
			
			* compute p value for sum of lags
			scalar z = abs(lagsumNW_coef_opt/lagsumNW_se_opt)
			scalar p = exp((0.743 - (z+0.862)^2)/2.404)
			
			if p < 0.01 {
				loc lagsumstar_`instrspec'_opt "***"
			}
			else if p >= 0.01 & p < 0.05 {
				loc lagsumstar_`instrspec'_opt "**"					
			}
			else if p >= 0.05 & p < 0.1 {
				loc lagsumstar_`instrspec'_opt "*"					
			}				
			else {
				loc lagsumstar_`instrspec'_opt ""
			}			
		
			* store lagsum, threshold scalars and other stats
			scalar lagsumCoef_`instrspec'_opt = lagsumNW_coef_opt
			scalar lagsumSE_`instrspec'_opt = lagsumNW_se_opt
			scalar t_hat_`instrspec' = gstar_2
			scalar nobs_`instrspec'_opt = nobs_opt
			
			scalar pval_`instrspec'_opt = coeftest_c_opt

			
			
	}
		}


		local sample_count `=`sample_count'+1'
}	



***********
* TABLE 3 (Cols 1-2):
***********
// Linear estimates
esttab lin_spliced lin_WuXia  ///
	using "../tables/table3cols1-2.tex", /*rename(`nameList1')*/ keep(u_gap) nomti $regopts replace ///
	noobs coeflabel(u_gap "Slope, $\hat{\kappa}$") ///
	prehead(`ph_general' "& \multicolumn{2}{c}{Unemployment Gap} \\" ///
	 "& \multicolumn{1}{c}{Federal funds rate} & \multicolumn{1}{c}{Wu & Xia shadow rate } \\" ///
	"\hline \multicolumn{3}{c}{\textit{Panel A: Linear Model}}\\"  ) posthead("")

// Slope estimates, threshold model
esttab t_spliced_opt t_WuXia_opt ///
	using "../tables/table3cols1-2.tex", /*rename(`nameList2')*/ keep(u_gap* ) $regopts noobs nomti append ///
	coeflabel(u_gap_left "left, $\hat{\kappa}_L$" u_gap_right "right, $\hat{\kappa}_R$") substitute("\_" "_") ///
	prehead("\hline \multicolumn{3}{c}{\textit{Panel B: Threshold Model}}\\" " \textit{Slopes} \\") posthead("")

// Expectations, threshold model
esttab t_spliced_opt t_WuXia_opt ///
	using "../tables/table3cols1-2", /*rename(`nameList2')*/ keep(exp_infl*) $regopts noobs nomti append ///
	coeflabel(exp_infl_MI_cns "UMSC, $\hat{\alpha}_2$" exp_infl_SPF_gdp_cns "SPF, $\hat{\alpha}_1$") substitute("\_" "_")  ///
	prehead(" \textit{Expected Inflation} \\") posthead("")

// Sum of lags, threshold ests and other stats, threshold model
qui {
log using "../tables/table3cols1-2.tex",  append
n di %13s "\hspace{1em}Sum of lags, $\hat{\alpha}_0$ & "  /// 
	%5.2f lagsumCoef_spliced_opt "\sym{`lagsumstar_spliced_opt'} & "  ///
	%5.2f lagsumCoef_WuXia_opt "\sym{`lagsumstar_WuXia_opt'} & " 
n di %14s "& (" ///
	%4.2f lagsumSE_spliced_opt ") & ("  ///
	%4.2f lagsumSE_WuXia_opt ") \\" 


n di "\emph{Threshold}, $\hat{\gamma}$  \\"
 n di %13s "\hspace{1em}point estimate & "  /// 
	%5.2f t_hat_spliced " & "  ///
	%5.2f t_hat_WuXia " \\" 

	


	 n di %13s "Test p-value ($\ H_0$: Linear model) & " ///
		%5.2f pval_spliced_opt " & "  ///
		%5.2f pval_WuXia_opt " \\ " 


	
 n di %13s "$\ N$ & "  /// 
	%5.0fc nobs_spliced_opt " & "  ///
	%5.0fc nobs_WuXia_opt " \\ " 


n di"\bottomrule" 
n di "\end{tabular}"
log cl
}







