// Table 4

clear all
set more off, perm
set matsize 10000
set logtype tex
set linesize 150

loc do_dir subroutines
use "../data/AggregatePC.dta", clear

loc number_lags 5

* create lags
foreach var of var infl* P_fdEnrgy_chng exp_infl_MI {
	forv ll = 0/`number_lags' {
		g l`ll'_`var' = l`ll'.`var'
	}
}

* create 'explained' expectations, controlling for lags and volatile prices
reg exp_infl_MI l1_exp_infl_MI-l4_exp_infl_MI l1_inflcpi_rt - l4_inflcpi_rt L1.ffr L.exp_infl_SPF_gdp d_oil

* create 1 step ahead and dynamic fcasts of MI w/ and w/o oil
predict MI_hat, xb 
la var MI_hat "1 step, w/ oil"

la var MI_hat "Explained portion of MI expectations"

*** Compute forecasts and create figures

forval spec=2/2 {
* define the unemployment variable (u_rate in Spec1, u_gap in Spec2)
if `spec'==1 {
	loc measure = "u_rate"
}
else if `spec'==2 {
	loc measure = "u_gap"
	gen l1_`measure' = L1.u_gap
}
else if `spec'==3 {
	loc measure = "labor_share"
	gen l1_`measure' = L1.labor_share
}
else if `spec'==4 {
	loc measure = "labor_share_alt"
	gen l1_`measure' = L1.labor_share_alt
}
* Store general controls, piecewise controls & backward-looking exp terms (lags)
foreach var of var infl* { // PCE and CPI core
	loc `var'_controls "l1_P_fdEnrgy_chng - l2_P_fdEnrgy_chng gordon"
	qui ds `measure' 
	loc `var'_pcsws_ctrls "`r(varlist)'"
	loc `var'_backexp "l1_`var' - l5_`var'"
}


* define threshold variable: contemp. for PCE and CPI, first lag for GDP deflator

loc Uthresh_infl_pce_core  `measure'
loc Uthresh_infl_pce `measure'
loc Uthresh_infl_cpi_core  `measure'
loc Uthresh_infl_cpi  `measure'
loc Uthresh_infl_gdp  `measure'

* expectation measures to use:
loc fwdexp exp_infl_MI exp_infl_SPF_gdp
loc fwdexp2 MI_hat exp_infl_SPF_gdp 


	foreach var of var infl_cpi {
		* MI, SPF GDP & backward looking exp
		loc expvars = "`fwdexp'" + " " + "``var'_backexp'"
		loc expvars_2 = "`fwdexp2'" + " " + "``var'_backexp'"
		
		
		loc start_date `=tq(1976q2)'
		preserve
		do "`do_dir'/estTable4.do" `var' `Uthresh_`var'' "``var'_pcsws_ctrls'" "``var'_controls'" "`expvars'" "`expvars_2'" `start_date'

		// Save forecast estimates for table 4
		scalar d1_infl = d1_chg_infl_cpi
		scalar d1_linest =d1_chg_lin_dyn_infl_cpi_mihat
		scalar d1_linmsc =d1_chg_lin_dyn_infl_cpi_mispf
		scalar d1_test =d1_chg__1thr_dyn_infl_cpi_mihat
		scalar d1_tmsc =d1_chg__1thr_dyn_infl_cpi_mispf		
		
		scalar rmse1_linest =rmse1_residsq_lin_dyn_mihat
		scalar rmse1_linmsc =rmse1_residsq_lin_dyn_mispf
		scalar rmse1_test =rmse1_residsq_dyn_mihat
		scalar rmse1_tmsc =rmse1_residsq_dyn_mispf		
		
		restore
		
	
		
		loc start_date `=tq(1979q4)'
		preserve
		do "`do_dir'/estTable4.do" `var' `Uthresh_`var'' "``var'_pcsws_ctrls'" "``var'_controls'" "`expvars'" "`expvars_2'" `start_date'

		scalar d2_infl = d2_chg_infl_cpi
		scalar d2_linest =d2_chg_lin_dyn_infl_cpi_mihat
		scalar d2_linmsc =d2_chg_lin_dyn_infl_cpi_mispf
		scalar d2_test =d2_chg__1thr_dyn_infl_cpi_mihat
		scalar d2_tmsc =d2_chg__1thr_dyn_infl_cpi_mispf		

		scalar rmse2_linest =rmse2_residsq_lin_dyn_mihat
		scalar rmse2_linmsc =rmse2_residsq_lin_dyn_mispf
		scalar rmse2_test =rmse2_residsq_dyn_mihat
		scalar rmse2_tmsc =rmse2_residsq_dyn_mispf			
	
		
		restore	
	
	}
	
}

* Generate table 4
qui {

log using "../tables/table4.tex", tex replace

n di "\begin{tabular}{c*{5}c@{}} \toprule "
n di "& \multicolumn{2}{c}{Great Inflation} & \multicolumn{2}{c}{Volcker Disinflation} \\"
n di "\cline{2-3}\cline{4-5}"
n di "&  \multicolumn{1}{c}{Peak-to-Trough} & & \multicolumn{1}{c}{Peak-to-Trough} & \\"
n di "Inflation &  \multicolumn{1}{c}{Change, p.p.} & RMSE & \multicolumn{1}{c}{Change, p.p.} & RMSE \\"
n di "& \multicolumn{1}{c}{(1)} & \multicolumn{1}{c}{(2)} & \multicolumn{1}{c}{(3)} & \multicolumn{1}{c}{(4)}\\" 

n di "\hline"

n di %13s "CPI Inflation & "  /// 
	%5.2f d1_infl " & & "  ///
	%5.2f d2_infl " & \\ "

n di "\textit{Linear Model} \\"
	
n di %13s "\hspace{1em} actual expectations & "  /// 
	%5.2f d1_linmsc " & "  ///
	%5.2f rmse1_linmsc " & " ///
	%5.2f d2_linmsc " & " ///
	%5.2f rmse2_linmsc " \\ "

n di "\textit{Threshold Model} \\"
	
n di %13s "\hspace{1em} actual & "  /// 
	%5.2f d1_tmsc " & "  ///
	%5.2f rmse1_tmsc " & " ///
	%5.2f d2_tmsc " & " ///
	%5.2f rmse2_tmsc " \\ "

n di"\bottomrule" 
n di "\end{tabular}"
log cl
}
