// Table 5

loc isCIsig 1 // toggle 1/0 to obtain confidence intervals/significance for threshold (slow)


clear all
set more off, perm
cap log close
set logtype tex
set linesize 150

// Define esttab options
#delimit ;
glob regopts = "cells(b(star fmt(2)) se(par fmt(2))) star( * 0.1 ** 0.05 *** 0.01)
collabels(none)  obslast nonumber nonotes nogaps booktabs fragment";
#delimit cr

loc ph_general `" "\begin{tabular}{c*{@span}c@{}}" \toprule  "'
loc pf_general `" "\bottomrule" \end{tabular} "'

loc do_dir subroutines
use "../data/AggregatePC.dta", clear

* create firm interest rates
qui ds cred*
foreach vv in `r(varlist)' {
	gen rate_`vv' = `vv'+ffr
}


* create lags
foreach var of var infl* P_fdEnrgy_chng neer_dollar_chng {
	forv ll = 0/5 {
		g l`ll'_`var' = l`ll'.`var'
	}
}
foreach measure in u_gap { 

* Store general controls, piecewise controls & backward-looking exp terms (lags)
foreach var of var infl*core infl_pce infl_cpi infl_gdp { // PCE and CPI core
	qui ds `measure' 
	loc `var'_pcsws_ctrls "`r(varlist)'"
	loc `var'_backexp "l1_`var' - l5_`var'"
}

* define threshold variable: contemp. for PCE and CPI, first lag for GDP deflator

loc Uthresh_infl_pce_core  `measure'
loc Uthresh_infl_pce  `measure'
loc Uthresh_infl_cpi_core  `measure'
loc Uthresh_infl_cpi  `measure'
loc Uthresh_infl_gdp  `measure'

* expectation measures to use:

loc fwdexp  exp_infl_MI  exp_infl_SPF_gdp

local sample_count 1

keep if exp_infl_SPF_gdp!=.
	foreach var of var infl_cpi {
		
		foreach cc in credsp cred_gzspr cred_ebp_oa "" {		
			* MI, SPF GDP & backward looking exp
			loc expvars = "`fwdexp'" + " " + "``var'_backexp'"
			
    // Confidence intervals requested?
    if `isCIsig' loc CIsig Y
    else loc CIsig N
      
			preserve
			if "`cc'"=="" {
				loc `var'_controls "l1_P_fdEnrgy_chng - l2_P_fdEnrgy_chng l1_neer_dollar_chng - l2_neer_dollar_chng gordon"
				drop if mi(cred_ebp_oa) // keep to the GZ sample, no credit sp
				do "`do_dir'/estimationTables" `var' `Uthresh_`var'' "``var'_pcsws_ctrls'" "``var'_controls'" "`expvars'"  `CIsig'
				
			}			
			else {
				loc `var'_controls "rate_`cc' l1_P_fdEnrgy_chng - l2_P_fdEnrgy_chng l1_neer_dollar_chng - l2_neer_dollar_chng gordon"
				do "`do_dir'/estimationTables_credit" `var' `Uthresh_`var'' "``var'_pcsws_ctrls'" "``var'_controls'" `cc' "`expvars'" `CIsig'
			}
			
			loc nameList `nameList' `Uthresh_`var''_left_cns thresh_left `Uthresh_`var''_right_cns thresh_right
		
			* compute p value for sum of lags
			scalar z = abs(lagsumNW_coef/lagsumNW_se)
			scalar p = exp((0.743 - (z+0.862)^2)/2.404)
			
			if p < 0.01 {
				loc lagsumstar_`var'_`cc' "***"
			}
			else if p >= 0.01 & p < 0.05 {
				loc lagsumstar_`var'_`cc' "**"					
			}
			else if p >= 0.05 & p < 0.1 {
				loc lagsumstar_`var'_`cc' "\ *"					
			}				
			else {
				loc lagsumstar_`var'_`cc' ""
			}			
		
			* store lagsum, threshold scalars and other stats
			scalar lagsumCoef_`var'_`cc' = lagsumNW_coef
			scalar lagsumSE_`var'_`cc' = lagsumNW_se
			scalar t_hat_`var'_`cc' = gstar_`var'_2
			scalar Rsq_`var'_`cc' = Rsq
			scalar nobs_`var'_`cc' = nobs
			
		if `isCIsig' {		
			scalar pval_`var'_`cc' = pval
			scalar gU_`var'_`cc' = gamma_Uci
			scalar gL_`var'_`cc' = gamma_Lci					
		}	
			restore
		}

	}
	
}


* output to tex:
// Linear estimates
esttab lin_infl_cpi_credsp lin_infl_cpi_cred_gzspr lin_infl_cpi_cred_ebp_oa lin_infl_cpi_u_gap ///
	using "../tables/table5.tex", rename(u_gap thresh) keep(thresh) nomti $regopts replace ///
	noobs coeflabel(thresh "Slope, $\hat{\beta}$") ///
	prehead(`ph_general' "& \multicolumn{1}{c}{Baa-Aaa} & \multicolumn{1}{c}{GZ Credit} & \multicolumn{1}{c}{Excess Bond} & \multicolumn{1}{c}{Fixed} \\" ///
	"& \multicolumn{1}{c}{Spread} & \multicolumn{1}{c}{Spread} & \multicolumn{1}{c}{Premium} & \multicolumn{1}{c}{Sample} \\" ///
	"& \multicolumn{1}{c}{(1)} & \multicolumn{1}{c}{(2)} & \multicolumn{1}{c}{(3)} & \multicolumn{1}{c}{(4)}\\" ///
	"\hline \multicolumn{5}{c}{\textit{Panel A: Linear Model}}\\"  ) posthead("")

// Slope estimates, threshold model
esttab t_infl_cpi_credsp t_infl_cpi_cred_gzspr t_infl_cpi_cred_ebp_oa t_infl_cpi_u_gap ///
	using "../tables/table5.tex", rename(`nameList' rate_credsp credit rate_cred_gzspr credit rate_cred_ebp_oa credit) keep(thresh* credit) ///
	$regopts noobs nomti append ///
	coeflabel(thresh_left "left, $\hat{\beta}_L$" thresh_right "right, $\hat{\beta}_R$" credit "Spread Coefficient") substitute("\_" "_") ///
	prehead("\hline \multicolumn{5}{c}{\textit{Panel B: Threshold Model}}\\" " \textit{Slopes} \\") posthead("")

// Expectations and credit spread, threshold model
esttab t_infl_cpi_credsp t_infl_cpi_cred_gzspr t_infl_cpi_cred_ebp_oa t_infl_cpi_u_gap ///
	using "../tables/table5.tex", keep(exp*) $regopts noobs nomti append ///
	coeflabel(exp_infl_MI_cns "UMSC, $\hat{\alpha}_2$" exp_infl_SPF_gdp_cns "SPF, $\hat{\alpha}_1$")  ///
	 substitute("\_" "_") prehead(" \textit{Expected Inflation} \\") posthead("")

// Sum of lags, threshold ests and other stats, threshold model
qui {
log using "../tables/table5.tex", tex append
n di %13s "\hspace{1em}Sum of lags, $\hat{\alpha}_0$ & "  /// 
	%5.2f lagsumCoef_infl_cpi_credsp "\sym{`lagsumstar_infl_cpi_credsp'} & "  ///
	%5.2f lagsumCoef_infl_cpi_cred_gzspr "\sym{`lagsumstar_infl_cpi_cred_gzspr'} & " ///
	%5.2f lagsumCoef_infl_cpi_cred_ebp_oa "\sym{`lagsumstar_infl_cpi_cred_ebp_oa'} & " ///
	%5.2f lagsumCoef_infl_cpi_ "\sym{`lagsumstar_infl_cpi_'} \\  "
n di %14s "& (" ///
	%4.2f lagsumSE_infl_cpi_credsp ") & ("  ///
	%4.2f lagsumSE_infl_cpi_cred_gzspr ") & ("  ///
	%4.2f lagsumSE_infl_cpi_cred_ebp_oa ") & ("  ///
	%4.2f lagsumSE_infl_cpi_ ") \\ "

n di "\emph{Threshold}, $\hat{\gamma}$  \\"
 n di %13s "\hspace{1em}point estimate & "  /// 
	%5.2f t_hat_infl_cpi_credsp " & "  ///
	%5.2f t_hat_infl_cpi_cred_gzspr " & " ///
	%5.2f t_hat_infl_cpi_cred_ebp_oa " & " ///
	%5.2f t_hat_infl_cpi_ " \\" 

if `isCIsig' {	
n di "\hspace{1em}95\% confidence interval & [" ///
	%5.2f gL_infl_cpi_credsp "," %5.2f gU_infl_cpi_credsp "] & ["  ///
	%5.2f gL_infl_cpi_cred_gzspr "," %5.2f gU_infl_cpi_cred_gzspr "] & ["  ///
	%5.2f gL_infl_cpi_cred_ebp_oa "," %5.2f gU_infl_cpi_cred_ebp_oa "] & ["  ///
	%5.2f gL_infl_cpi_ "," %5.2f gU_infl_cpi_ "] \\"
	
n di "\emph{No. of thresholds, $\ p$-val.} \\"

 n di %13s "\hspace{1em}0 vs.\ 1, $\ H_0$: 0 & " ///
	%5.2f pval_infl_cpi_credsp " & "  ///
	%5.2f pval_infl_cpi_cred_gzspr " & " ///
	%5.2f pval_infl_cpi_cred_ebp_oa " & " ///
	%5.2f pval_infl_cpi_ " \\" 
}
n di "\hspace{1em}1 vs.\ 2, $\ H_0$: 1  & & & & \\"

 n di %13s "$\ R^{2}$ & "  /// 
	%5.2f Rsq_infl_cpi_credsp " & "  ///
	%5.2f Rsq_infl_cpi_cred_gzspr " & " ///
	%5.2f Rsq_infl_cpi_cred_ebp_oa " & " ///
	%5.2f Rsq_infl_cpi_ " \\" 
	
 n di %13s "$\ N$ & "  /// 
	%5.0fc nobs_infl_cpi_credsp " & "  ///
	%5.0fc nobs_infl_cpi_cred_gzspr " & " ///
	%5.0fc nobs_infl_cpi_cred_ebp_oa " & " ///
	%5.0fc nobs_infl_cpi_ " \\" 	

n di"\bottomrule" 
n di "\end{tabular}"
log cl
}

