
clear all
set more off, perm
cap log close
set logtype tex
set linesize 150

// Define esttab options
#delimit ;
glob regopts = "cells(b(star fmt(2)) se(par fmt(2))) star( * 0.1 ** 0.05 *** 0.01)
collabels(none)  obslast nonumber nonotes nogaps booktabs fragment";
#delimit cr

loc ph_general `" "\begin{tabular}{c*{@span}c@{}}" \toprule  "'
loc pf_general `" "\bottomrule" \end{tabular} "'

loc do_dir subroutines

use "../data/AggregatePC.dta", clear

* create firm interest rates
qui ds cred*
foreach vv in `r(varlist)' {
	gen rate_`vv' = `vv'+ffr
}


* create lags
foreach var of var infl*  P_fdEnrgy_chng neer_dollar_chng {
	forv ll = 0/5 {
		g l`ll'_`var' = l`ll'.`var'
	}
}
foreach measure in u_gap { 

* Store general controls, piecewise controls & backward-looking exp terms (lags)
foreach var of var infl*core infl_pce infl_cpi infl_gdp { // PCE and CPI core
	qui ds `measure' 
	loc `var'_pcsws_ctrls "`r(varlist)'"
	loc `var'_backexp "l1_`var' - l5_`var'"
}

* define threshold variable: contemp. for PCE and CPI, first lag for GDP deflator

loc Uthresh_infl_pce_core  `measure'
loc Uthresh_infl_pce  `measure'
loc Uthresh_infl_cpi_core  `measure'
loc Uthresh_infl_cpi  `measure'
loc Uthresh_infl_gdp  `measure'

* expectation measures to use:

loc fwdexp  exp_infl_MI  exp_infl_SPF_gdp

local sample_count 1

keep if exp_infl_SPF_gdp!=.
	foreach var of var infl_pce infl_gdp {
		
		foreach cc in credsp cred_gzspr cred_ebp_oa {		
			preserve
			
			* MI, SPF GDP & backward looking exp
			loc expvars = "`fwdexp'" + " " + "``var'_backexp'"
			
			loc `var'_controls "rate_`cc' l1_P_fdEnrgy_chng - l2_P_fdEnrgy_chng l1_neer_dollar_chng - l2_neer_dollar_chng gordon"
			
			do "`do_dir'/estimationTables_2v1" `var' `Uthresh_`var'' "``var'_pcsws_ctrls'" "``var'_controls'" "`expvars'" Y	
			
			* store stats
			scalar pval_`var'_`cc' = pval
			restore
		}

	}
	
}


* output to tex:
qui {
log using "../tables/tableB10_2v1.tex", tex replace
	
n di %13s "& \multicolumn{2}{c}{Baa-Aaa Spread} & \multicolumn{2}{c}{GZ Credit Spread} & \multicolumn{2}{c}{Excess Bond Premium} \\"
n di %13s "\cline{2-3}\cline{4-5}\cline{6-7}"
n di %13s "& \multicolumn{1}{c}{GDP} & \multicolumn{1}{c}{PCE} & \multicolumn{1}{c}{GDP} & \multicolumn{1}{c}{PCE} & \multicolumn{1}{c}{GDP} & \multicolumn{1}{c}{PCE} \\"
n di %13s "& \multicolumn{1}{c}{(1)} & \multicolumn{1}{c}{(2)} & \multicolumn{1}{c}{(3)} & \multicolumn{1}{c}{(4)} & \multicolumn{1}{c}{(5)} & \multicolumn{1}{c}{(6)} \\"

	
n di "\emph{No. of thresholds, $\ p$-val.} \\"

 n di %13s "\hspace{1em}1 vs.\ 2, $\ H_0$: 1 & " ///
 	%5.2f pval_infl_gdp_credsp " & "  ///
	%5.2f pval_infl_pce_credsp " & "  ///	
 	%5.2f pval_infl_gdp_cred_gzspr " & "  ///
	%5.2f pval_infl_pce_cred_gzspr " & "  ///
 	%5.2f pval_infl_gdp_cred_ebp_oa " & "  ///
	%5.2f pval_infl_pce_cred_ebp_oa " \\ " 
log cl
}

