/*
	Generates 2 v 1 p-values for table B2
*/

clear all
set more off, perm
cap log close
set logtype tex
set linesize 150

// Define esttab options
#delimit ;
glob regopts = "cells(b(star fmt(2)) se(par fmt(2))) star( * 0.1 ** 0.05 *** 0.01)
collabels(none)  obslast nonumber nonotes nogaps booktabs fragment";
#delimit cr

loc ph_general `" "\begin{tabular}{c*{@span}c@{}}" \toprule  "'
loc pf_general `" "\bottomrule" \end{tabular} "'


loc do_dir subroutines

use "../data/AggregatePC.dta", clear



* create lags
foreach var of var infl*  P_fdEnrgy_chng neer_dollar_chng {
	forv ll = 0/5 {
		g l`ll'_`var' = l`ll'.`var'
	}
}
foreach measure in u_rate u_gap labor_share ls_alt { 

* Store general controls, piecewise controls & backward-looking exp terms (lags)
foreach var of var infl*core infl_pce infl_cpi infl_gdp { // PCE and CPI core
	loc `var'_controls "l1_P_fdEnrgy_chng - l2_P_fdEnrgy_chng l1_neer_dollar_chng - l2_neer_dollar_chng gordon"
	qui ds `measure' 
	loc `var'_pcsws_ctrls "`r(varlist)'"
	loc `var'_backexp "l1_`var' - l5_`var'"
}

* define threshold variable: contemp. for PCE and CPI, first lag for GDP deflator

loc Uthresh_infl_pce_core  `measure'
loc Uthresh_infl_pce  `measure'
loc Uthresh_infl_cpi_core  `measure'
loc Uthresh_infl_cpi  `measure'
loc Uthresh_infl_gdp  `measure'

* expectation measures to use:

loc fwdexp exp_infl_SPF_gdp

local sample_count 1

keep if exp_infl_SPF_gdp!=.
	foreach var of var infl_cpi {

		* MI, SPF GDP & backward looking exp
		loc expvars = "`fwdexp'" + " " + "``var'_backexp'"
		
		preserve
		do "`do_dir'/estimationTables_2v1" `var' `Uthresh_`var'' "``var'_pcsws_ctrls'" "``var'_controls'" "`expvars'" Y
		loc nameList1 `nameList1' `Uthresh_`var'' thresh
		loc nameList2 `nameList2' `Uthresh_`var''_left_cns thresh_left `Uthresh_`var''_right_cns thresh_right
	
		* store lagsum, threshold scalars and other stats		
		scalar pval_`measure' = pval
		
		restore

	}
	
}


* output to tex:
*2v1 p-value
qui {
log using "../tables/tableB2_2v1.tex", tex replace

n di %13s "& \multicolumn{2}{c}{Unemployment} & \multicolumn{2}{c}{Labor Share} \\"
n di %13s "\cline{2-3}\cline{4-5}"
n di %13s "& \multicolumn{1}{c}{Gap} & \multicolumn{1}{c}{Rate} & \multicolumn{1}{c}{Raw} & \multicolumn{1}{c}{Adjusted}\\"

n di "\emph{No. of thresholds, $\ p$-val.} \\"

n di %13s "\hspace{1em}1 vs.\ 2, $\ H_0$: 1 & " ///
	%5.2f pval_u_gap " & "  ///
	%5.2f pval_u_rate " & " ///
	%5.2f pval_labor_share " & " ///
	%5.2f pval_ls_alt " \\" 
	
log cl
}

