// Table B6 in the paper
loc isCIsig 1 // toggle 1/0 to obtain confidence intervals/significance for threshold (slow)

clear all
set more off, perm
cap log close
set logtype tex
set linesize 150

// Define esttab options
#delimit ;
glob regopts = "cells(b(star fmt(2)) se(par fmt(2))) star( * 0.1 ** 0.05 *** 0.01)
collabels(none)  obslast nonumber nonotes nogaps booktabs fragment";
#delimit cr

loc ph_general `" "\begin{tabular}{c*{@span}c@{}}" \toprule  "'
loc pf_general `" "\bottomrule" \end{tabular} "'

loc do_dir subroutines

use "../data/AggregatePC.dta", clear

* create lags
foreach var of var infl* P_fdEnrgy_chng neer_dollar_chng {
	forv ll = 0/5 {
		g l`ll'_`var' = l`ll'.`var'
	}
}

rename labor_share ls // long var name truncation error
foreach measure in u_rate u_gap ls ls_alt { 

* Store general controls, piecewise controls & backward-looking exp terms (lags)
foreach var of var infl*core infl_pce infl_cpi infl_gdp { // PCE and CPI core
	loc `var'_controls "l1_P_fdEnrgy_chng - l2_P_fdEnrgy_chng l1_neer_dollar_chng - l2_neer_dollar_chng gordon"
	qui ds `measure' /*l0_d_u_rate - l2_d_u_rate*/
	loc `var'_pcsws_ctrls "`r(varlist)'"
	loc `var'_backexp "l1_`var' - l5_`var'"
}

* define threshold variable: contemp. for PCE and CPI, first lag for GDP deflator

loc Uthresh_infl_pce_core  `measure'
loc Uthresh_infl_pce  `measure'
loc Uthresh_infl_cpi_core  `measure'
loc Uthresh_infl_cpi  `measure'
loc Uthresh_infl_gdp  `measure'

* expectation measures to use:

loc fwdexp  exp_infl_MI  exp_infl_SPF_gdp

local sample_count 1

keep if exp_infl_SPF_gdp!=.
	foreach var of var infl_pce_core {

		* MI, SPF GDP & backward looking exp
		loc expvars = "`fwdexp'" + " " + "``var'_backexp'"
		
    // Confidence intervals requested?
    if `isCIsig' loc CIsig Y
    else loc CIsig N 
    
		preserve
		do "`do_dir'/estimationTables" `var' `Uthresh_`var'' "``var'_pcsws_ctrls'" "``var'_controls'" "`expvars'" `CIsig'
		loc nameList1 `nameList1' `Uthresh_`var'' thresh
		loc nameList2 `nameList2' `Uthresh_`var''_left_cns thresh_left `Uthresh_`var''_right_cns thresh_right
		
		* compute p value for sum of lags
		scalar z = abs(lagsumNW_coef/lagsumNW_se)
		scalar p = exp((0.743 - (z+0.862)^2)/2.404)
		
		if p < 0.01 {
			loc lagsumstar_`var'_`measure' "***"
		}
		else if p >= 0.01 & p < 0.05 {
			loc lagsumstar_`var'_`measure' "**"					
		}
		else if p >= 0.05 & p < 0.1 {
			loc lagsumstar_`var'_`measure' "*"					
		}				
		else {
			loc lagsumstar_`var'_`measure' ""
		}			
	
		* store lagsum, threshold scalars and other stats
		scalar lagsumCoef_`var'_`measure' = lagsumNW_coef
		scalar lagsumSE_`var'_`measure' = lagsumNW_se
		scalar t_hat_`var'_`measure' = gstar_`var'_2
		scalar Rsq_`var'_`measure' = Rsq
		scalar nobs_`var'_`measure' = nobs
		
	if `isCIsig' {		
		scalar pval_`measure' = pval
		scalar gU_`measure' = gamma_Uci
		scalar gL_`measure' = gamma_Lci			
	}	
		restore

	}
	
}


* output to tex:
// Linear estimates
esttab lin_infl_pce_core_u_gap lin_infl_pce_core_u_rate lin_infl_pce_core_ls lin_infl_pce_core_ls_alt ///
	using "../tables/tableB6.tex", rename(`nameList1') keep(thresh) nomti $regopts replace ///
	noobs coeflabel(thresh "Slope, $\hat{\beta}$") ///
	prehead(`ph_general' "& \multicolumn{2}{c}{Unemployment} & \multicolumn{2}{c}{Labor Share} \\" ///
	"\cline{2-3}\cline{4-5}" "& \multicolumn{1}{c}{Gap} & \multicolumn{1}{c}{Rate} & \multicolumn{1}{c}{Raw} & \multicolumn{1}{c}{Adjusted}\\" ///
	"& \multicolumn{1}{c}{(1)} & \multicolumn{1}{c}{(2)} & \multicolumn{1}{c}{(3)} & \multicolumn{1}{c}{(4)}\\" ///
	"\hline \multicolumn{5}{c}{\textit{Panel A: Linear Model}}\\"  ) posthead("")

// Slope estimates, threshold model
esttab t_infl_pce_core_u_gap t_infl_pce_core_u_rate t_infl_pce_core_ls t_infl_pce_core_ls_alt ///
	using "../tables/tableB6.tex", rename(`nameList2') keep(thresh* ) $regopts noobs nomti append ///
	coeflabel(thresh_left "left, $\hat{\beta}_L$" thresh_right "right, $\hat{\beta}_R$") substitute("\_" "_") ///
	prehead("\hline \multicolumn{5}{c}{\textit{Panel B: Threshold Model}}\\" " \textit{Slopes} \\") posthead("")

// Expectations, threshold model
esttab t_infl_pce_core_u_gap t_infl_pce_core_u_rate t_infl_pce_core_ls t_infl_pce_core_ls_alt ///
	using "../tables/tableB6.tex", rename(`nameList2') keep(exp*) $regopts noobs nomti append ///
	coeflabel(exp_infl_MI_cns "UMSC, $\hat{\alpha}_2$" exp_infl_SPF_gdp_cns "SPF, $\hat{\alpha}_1$") substitute("\_" "_")  ///
	prehead(" \textit{Expected Inflation} \\") posthead("")

// Sum of lags, threshold ests and other stats, threshold model
qui {
log using "../tables/tableB6.tex", tex append
n di %13s "\hspace{1em}Sum of lags, $\hat{\alpha}_0$ & "  /// 
	%5.2f lagsumCoef_infl_pce_core_u_gap "\sym{`lagsumstar_infl_pce_core_u_gap'} & "  ///
	%5.2f lagsumCoef_infl_pce_core_u_rate "\sym{`lagsumstar_infl_pce_core_u_rate'} & " ///
	%5.2f lagsumCoef_infl_pce_core_ls "\sym{`lagsumstar_infl_pce_core_ls'} & " ///
	%5.2f lagsumCoef_infl_pce_core_ls_alt "\sym{`lagsumstar_infl_pce_core_ls_alt'} \\ "
n di %14s "& (" ///
	%4.2f lagsumSE_infl_pce_core_u_gap ") & ("  ///
	%4.2f lagsumSE_infl_pce_core_u_rate ") & ("  ///
	%4.2f lagsumSE_infl_pce_core_ls ") & ("  ///
	%4.2f lagsumSE_infl_pce_core_ls_alt ") \\ "

n di "\emph{Threshold}, $\hat{\gamma}$  \\"
 n di %13s "\hspace{1em}point estimate & "  /// 
	%5.2f t_hat_infl_pce_core_u_gap " & "  ///
	%5.2f t_hat_infl_pce_core_u_rate " & " ///
	%5.2f t_hat_infl_pce_core_ls " & " ///
	%5.2f t_hat_infl_pce_core_ls_alt " \\" 

  if `isCIsig' {		
n di "\hspace{1em}95\% confidence interval & [" ///
	%5.2f gL_u_gap "," %5.2f gU_u_gap "] & ["  ///
	%5.2f gL_u_rate "," %5.2f gU_u_rate "] & ["  ///
	%5.2f gL_ls "," %5.2f gU_ls "] & ["  ///
	%5.2f gL_ls_alt "," %5.2f gU_ls_alt "] \\"
	
n di "\emph{No. of thresholds, $\ p$-val.} \\"

 n di %13s "\hspace{1em}0 vs.\ 1, $\ H_0$: 0 & " ///
 	%5.2f pval_u_gap " & "  ///
	%5.2f pval_u_rate " & " ///
	%5.2f pval_ls " & " ///
	%5.2f pval_ls_alt " \\" 
	}
  
n di "\hspace{1em}1 vs.\ 2, $\ H_0$: 1  & & & & \\"

 n di %13s "$\ R^{2}$ & "  /// 
	%5.2f Rsq_infl_pce_core_u_gap " & "  ///
	%5.2f Rsq_infl_pce_core_u_rate " & " ///
	%5.2f Rsq_infl_pce_core_ls " & " ///
	%5.2f Rsq_infl_pce_core_ls_alt " \\" 
	
 n di %13s "$\ N$ & "  /// 
	%5.0fc nobs_infl_pce_core_u_gap " & "  ///
	%5.0fc nobs_infl_pce_core_u_rate " & " ///
	%5.0fc nobs_infl_pce_core_ls " & " ///
	%5.0fc nobs_infl_pce_core_ls_alt " \\" 	

n di"\bottomrule" 
n di "\end{tabular}"
log cl
}

