// Table B8 in the paper

clear all
set more off, perm
set matsize 10000
set logtype tex
set linesize 150

loc do_dir subroutines

use "../data/AggregatePC.dta", clear
loc number_lags 5 //in quarters


* create lags
foreach var of var infl* P_fdEnrgy_chng exp_infl_MI {
	forv ll = 0/`number_lags' {
		g l`ll'_`var' = l`ll'.`var'
	}
}

* create 'explained' expectations, controlling for lags and volatile prices
reg exp_infl_MI l1_exp_infl_MI-l4_exp_infl_MI l1_inflcpi_rt - l4_inflcpi_rt L1.ffr L.exp_infl_SPF_gdp d_oil

* create 1 step ahead and dynamic fcasts of MI w/ and w/o oil
predict MI_hat, xb 
la var MI_hat "1 step, w/ oil"

la var MI_hat "Explained portion of MI expectations"

forval spec=2/2 {
* define the unemployment variable (u_rate in Spec1, u_gap in Spec2)
if `spec'==1 {
	loc measure = "u_rate"
}
else if `spec'==2 {
	loc measure = "u_gap"
	gen l1_`measure' = L1.u_gap
}
else if `spec'==3 {
	loc measure = "labor_share"
	gen l1_`measure' = L1.labor_share
}
else if `spec'==4 {
	loc measure = "labor_share_alt"
	gen l1_`measure' = L1.labor_share_alt
}
* Store general controls, piecewise controls & backward-looking exp terms (lags)
foreach var of var infl* { // PCE and CPI core
	loc `var'_controls "l1_P_fdEnrgy_chng - l2_P_fdEnrgy_chng gordon"
	qui ds `measure' 
	loc `var'_pcsws_ctrls "`r(varlist)'"
	loc `var'_backexp "l1_`var' - l5_`var'"
}


* define threshold variable: contemp. for PCE and CPI, first lag for GDP deflator

loc Uthresh_infl_pce_core  `measure'
loc Uthresh_infl_pce `measure'
loc Uthresh_infl_cpi_core  `measure'
loc Uthresh_infl_cpi  `measure'
loc Uthresh_infl_gdp  `measure'

* expectation measures to use:
loc fwdexp exp_infl_MI exp_infl_SPF_gdp
loc fwdexp2 MI_hat exp_infl_SPF_gdp 


	foreach var of var infl_cpi {
		* MI, SPF GDP & backward looking exp
		loc expvars = "`fwdexp'" + " " + "``var'_backexp'"
		loc expvars_2 = "`fwdexp2'" + " " + "``var'_backexp'"
		preserve
		do "`do_dir'/estTableB8.do" `var' `Uthresh_`var'' "``var'_pcsws_ctrls'" "``var'_controls'" "`expvars'" "`expvars_2'" "`sample'"

		// Save forecast estimates for table 3		
		scalar rmse_linest =rmse_residsq_lin_dyn_mihat
		scalar rmse_linmsc =rmse_residsq_lin_dyn_mispf
		scalar rmse_test =rmse_residsq_dyn_mihat
		scalar rmse_tmsc =rmse_residsq_dyn_mispf			
		restore
	}
	
}

qui {

log using "../tables/tableB8.tex", tex replace

n di "\begin{tabular}{c*{3}c@{}} \toprule "
n di "& \multicolumn{1}{c}{Estimated UMSC} & \multicolumn{1}{c}{Actual} \\"
n di "& \multicolumn{1}{c}{expectation} & \multicolumn{1}{c}{expectation} \\"
n di "& \multicolumn{1}{c}{(1)} & \multicolumn{1}{c}{(2)} \\"

n di "\hline"

n di %13s "Linear Model & "  /// 
	%5.2f rmse_linest " & " ///
	%5.2f rmse_linmsc " \\ "
	
n di %13s "Threshold Model & "  /// 
	%5.2f rmse_test " & " ///
	%5.2f rmse_tmsc " \\ "

n di"\bottomrule" 
n di "\end{tabular}"
log cl
}
