/*
	Generates subsample p-value estimates for Table C1
*/

clear all
set more off, perm
cap log close
set logtype tex
set linesize 150

// Define esttab options
#delimit ;
glob regopts = "cells(b(star fmt(2)) se(par fmt(2))) star( * 0.1 ** 0.05 *** 0.01)
collabels(none)  obslast nonumber nonotes nogaps booktabs fragment";
#delimit cr

loc ph_general `" "\begin{tabular}{c*{@span}c@{}}" \toprule  "'
loc pf_general `" "\bottomrule" \end{tabular} "'

loc do_dir subroutines

use "../data/AggregatePC.dta", clear


* create lags
foreach var of var infl* P_fdEnrgy_chng neer_dollar_chng {
	forv ll = 0/5 {
		g l`ll'_`var' = l`ll'.`var'
	}
}
foreach measure in u_gap { 

* Store general controls, piecewise controls & backward-looking exp terms (lags)
foreach var of var infl*core infl_pce infl_cpi infl_gdp { // PCE and CPI core
	loc `var'_controls "l1_P_fdEnrgy_chng - l2_P_fdEnrgy_chng l1_neer_dollar_chng - l2_neer_dollar_chng gordon"
	qui ds `measure' 
	loc `var'_pcsws_ctrls "`r(varlist)'"
	loc `var'_backexp "l1_`var' - l5_`var'"
}

* define threshold variable: contemp. for PCE and CPI, first lag for GDP deflator

loc Uthresh_infl_pce_core  `measure'
loc Uthresh_infl_pce  `measure'
loc Uthresh_infl_cpi_core  `measure'
loc Uthresh_infl_cpi  `measure'
loc Uthresh_infl_gdp  `measure'

* expectation measures to use:

loc fwdexp  exp_infl_MI  exp_infl_SPF_gdp

local sample_count 1

keep if exp_infl_SPF_gdp!=.
	foreach var of var infl_cpi {

		* MI, SPF GDP & backward looking exp
		loc expvars = "`fwdexp'" + " " + "``var'_backexp'"
		
		
		preserve
		do "`do_dir'/estimationTables" `var' `Uthresh_`var'' "``var'_pcsws_ctrls'" "``var'_controls'" "`expvars'" Y
		loc nameList1 `nameList1' `Uthresh_`var'' thresh
		loc nameList2 `nameList2' `Uthresh_`var''_left_cns thresh_left `Uthresh_`var''_right_cns thresh_right
		
		* compute p value for sum of lags
		scalar z = abs(lagsumNW_coef/lagsumNW_se)
		scalar p = exp((0.743 - (z+0.862)^2)/2.404)
		
		if p < 0.01 {
			loc lagsumstar_`var'_`measure' "***"
		}
		else if p >= 0.01 & p < 0.05 {
			loc lagsumstar_`var'_`measure' "**"					
		}
		else if p >= 0.05 & p < 0.1 {
			loc lagsumstar_`var'_`measure' "*"					
		}				
		else {
			loc lagsumstar_`var'_`measure' ""
		}			
	
		* store lagsum, threshold scalars and other stats
		scalar lagsumCoef_`var'_`measure' = lagsumNW_coef
		scalar lagsumSE_`var'_`measure' = lagsumNW_se
		scalar t_hat_`var'_`measure' = gstar_`var'_2
		scalar Rsq_`var'_`measure' = Rsq
		scalar nobs_`var'_`measure' = nobs
		
		scalar pval_`measure' = pval
		scalar gU_`measure' = gamma_Uci
		scalar gL_`measure' = gamma_Lci
		
		scalar pval_`measure'1 = pval1
		scalar pval_`measure'2 = pval2
		scalar pval_`measure'3 = pval3
		scalar pval_`measure'4 = pval4
		
		restore

	}
	
}


* Generate table C1
qui {

log using "../tables/tableC1.tex", tex replace

n di "\begin{tabular}{c*{2}c@{}} \toprule "
n di "& \multicolumn{1}{c}{p-value} \\"
n di "& \multicolumn{1}{c}{(1)} \\" 

n di "\hline"

n di %13s "Great Inflation & "  /// 
	%5.2f pval_u_gap1 " \\ "

n di %13s "Volcker disinflation & "  /// 
	%5.2f pval_u_gap2 " \\ "
	
n di %13s "Missing disinflation & "  /// 
	%5.2f pval_u_gap3 " \\ "
	
n di %13s "Missing inflation & "  /// 
	%5.2f pval_u_gap4 " \\ "
	
	
n di"\bottomrule" 
n di "\end{tabular}"
log cl
}
