// Tables E1, E2

clear all
set more off, perm


// Define esttab options
#delimit ;
glob regopts = "cells(b(star fmt(2)) se(par fmt(2))) star( * 0.1 ** 0.05 *** 0.01)
collabels(none) nomti obslast nonumber nonotes nogaps booktabs fragment";
#delimit cr

loc ph_general `" "\begin{tabular}{c*{@span}c@{}}" \toprule  "'
loc pf_general `" "\bottomrule" \end{tabular} "'

*** Take threshold as given
use "../data/RegionalPC.dta", clear

g year = year(dofh(halfyear))
g half = halfyear(dofh(halfyear))

loc gamma_star 7

gen left = .
replace left = 1 if u_rate<=`gamma_star'
replace left = 0 if mi(left)

gen right = .
replace right = 1 if !(u_rate<=`gamma_star')
replace right = 0 if mi(right)

constraint drop 1
constraint 1 `gamma_star'*(u_rate_left-u_rate_right) + (ones_left-ones_right) = 0

* create constant & urate for each state
gen ones = 1 
gen ones_left = ones*left
gen ones_right = ones*right
gen u_rate_left = u_rate*left
gen u_rate_right = u_rate*right

gen l_infl = L1.infl_cpi_core
				
* Estimate with and without expectations
foreach exp in "" exp_infl_MI {
	
	cap _eststo clear
	
	// pooled
	_eststo pool: cnsreg infl_cpi_core `exp' *_left *_right l_infl i.half , ///
		constraints(1) vce(cl area) nocons collinear
	test u_rate_left=u_rate_right
	estadd scalar slopeP = r(p)
	// area FE
	_eststo fe1: cnsreg infl_cpi_core `exp' *_left *_right l_infl i.half i.area , ///
		constraints(1) vce(cl area) nocons collinear
	test u_rate_left=u_rate_right
	estadd scalar slopeP = r(p)
	// year FE	
	_eststo fe2: cnsreg infl_cpi_core `exp' *_left *_right l_infl i.half i.year , ///
		constraints(1) vce(cl area) nocons collinear
	test u_rate_left=u_rate_right
	estadd scalar slopeP = r(p)
	// year and area FEs
	_eststo fe3: cnsreg infl_cpi_core `exp' *_left *_right l_infl i.half i.year i.area, ///
		constraints(1) vce(cl area) nocons collinear
	test u_rate_left=u_rate_right
	estadd scalar slopeP = r(p)
	
	if "`exp'" == "exp_infl_MI" {
		esttab pool fe1 fe2 fe3 using "../tables/tableE1.tex", replace ///
			$regopts keep(u_rate_* exp* l_infl) indicate("Year FE = *year*" "MSA FE = *area*") ///
			coeflabel(u_rate_left "left, $\hat{\beta}_L$" u_rate_right "right, $\hat{\beta}_R$" ///
			exp_infl_MI "UMSC, $\hat{\alpha}_1$" l_infl "Lagged CPI Core Inflation, $\hat{\alpha}_0$") ///
			stats(slopeP N , fmt(2 0)) substitute("slopeP" "$ p-val, \ H_0: \hat{\beta}_L = \hat{\beta}_R $") ///
			prehead(`ph_general' "& \multicolumn{4}{c}{Unemployment Rate} \\" "\cline{2-5}" ///
			"& \multicolumn{1}{c}{Pooled OLS} & \multicolumn{1}{c}{MSA FE only} & \multicolumn{1}{c}{Year FE Only} & \multicolumn{1}{c}{Year \& MSA FE} \\" ///
			"& \multicolumn{1}{c}{(1)} & \multicolumn{1}{c}{(2)} & \multicolumn{1}{c}{(3)} & \multicolumn{1}{c}{(4)} \\") ///
			postfoot(`pf_general')
	}
	else {
		esttab pool fe1 fe2 fe3 using "../tables/tableE2.tex", replace ///
			$regopts keep(u_rate_* l_infl) indicate("Year FE = *year*" "MSA FE = *area*") ///
			coeflabel(u_rate_left "left, $\hat{\beta}_L$" u_rate_right "right, $\hat{\beta}_R$" ///
			l_infl "Lagged CPI Core Inflation, $\hat{\alpha}_0$") ///
			stats(slopeP N , fmt(2 0)) substitute("slopeP" "$ p-val, \ H_0: \hat{\beta}_L = \hat{\beta}_R $") ///
			prehead(`ph_general' "& \multicolumn{4}{c}{Unemployment Rate} \\" "\cline{2-5}" ///
			"& \multicolumn{1}{c}{Pooled OLS} & \multicolumn{1}{c}{MSA FE only} & \multicolumn{1}{c}{Year FE Only} & \multicolumn{1}{c}{Year \& MSA FE} \\" ///
			"& \multicolumn{1}{c}{(1)} & \multicolumn{1}{c}{(2)} & \multicolumn{1}{c}{(3)} & \multicolumn{1}{c}{(4)} \\") ///
			postfoot(`pf_general')		
	}
} 
