***** Create figure with inflation predictions: linear (SPF and SPF+UMSC), threshold (SPF and SPF+UMSC)
***** Computes F-stat comparing the 2 regime case (no continuity) with the 3 regime case
***** F-stat p-values are obtained by bootstrapping
***** Order of args: inflation, threshold var, piecewise, exp & other controls, sample

args inflvar threshvar pcsws_ctrls controls expvars expvars_2
set matsize 11000

local percentile 10

sum quarter
local start_date  `=q(2017q1)' //`=r(min)'  // `=tq(2007q3)'
local end_date `=q(2019q4)' //`=r(max)'

if "`inflvar'"=="infl_pce_core" {
	label var infl_pce_core "PCE Core infl. (SAAR, %)"	
}
else if "`inflvar'"=="infl_pce" {
	label var infl_pce "PCE infl. (SAAR, %)"	
}	
* restrict dataset to regression sample
qui reg `inflvar' `expvars' `pcsws_ctrls' `controls'

gen tempsample = e(sample)
keep if tempsample == 1
drop tempsample

gen fcastSamp = quarter < `start_date'

* In case we decide to include difference of urate in regression, then it needs to be averaged for graph
if "`threshvar'"!="`pcsws_ctrls'" {
	if "`inflvar'"=="infl_gdp" {
		qui ds l1_d_u_rate - l4_d_u_rate
		local diffur "`r(varlist)'"
	}	
	else {
		qui ds l0_d_u_rate - l2_d_u_rate
		local diffur "`r(varlist)'"	
	}
}

else {
	local diffur //otherwise leave blank
}	

if "`threshvar' `diffur'"!= "`pcsws_ctrls'"  {
	if "`threshvar' `diffur'"!= "`pcsws_ctrls' " { //extra space might throw Stata off (coming from empty local)
		di "`threshvar'" "`diffur'"
		di "`pcsws_ctrls'"
		di ("`threshvar'`diffur'"=="`pcsws_ctrls'")
		di "Error in pcsws_ctrls specification"
		stop //to catch mistake in code
	}
}		

* Create expecatations constraint
qui ds `expvars'
scalar n_expvars = `=wordcount("`r(varlist)'")'
if n_expvars > 1 { // if more than 1 inflation expectations term
	loc expectations `=subinstr("`r(varlist)'"," ","+",.)' = 1
}	

qui ds `expvars_2'
scalar n_expvars_2 = `=wordcount("`r(varlist)'")'
if n_expvars_2 > 1 { // if more than 1 inflation expectations term
	loc expectations_2 `=subinstr("`r(varlist)'"," ","+",.)' = 1
}	

/* //check if the args passed successfully 
di "`inflvar'"
di "`threshvar'"
di "`pcsws_ctrls'"
di "`controls'"
di "`expectations'"
di "`sample'"
di "`boot'" 
di "`LR'"  
*/

cap log close
forval lag = 1/5 {
	gen l`lag'_`inflvar'_copy = l`lag'_`inflvar' //preserve lag copy to restore once we tweak it for dynamic model
}

* Estimate 1--with both MI and SPF - 
qui { // Display only counter & results
	* initialize SSR & gamma scalars for 2 -regime grid search
	scalar rm_`inflvar'_mispf = 100000
	scalar rm_`inflvar'_spf_ = 100000
	scalar gstar_`inflvar'_2 = -666
	
	**Linear -- MISPF*****************************************
	constraint drop _all
	// Constrain sum of inflation expectations to 1
	constraint 1 `expectations'
	
	if n_expvars > 1 {
		cnsreg `inflvar' `expvars' `pcsws_ctrls' `controls'  if fcastSamp, constraints(1)
	}
	else {
		reg `inflvar' `expvars' `pcsws_ctrls' `controls' if fcastSamp // reg still saves rmse & df_r in e()
	}
	

	
	*Linear prediction, 1 step ahead
	predict lin_1step_`inflvar'_mispf, xb
	lab var lin_1step_`inflvar'_mispf "Linear Model: MI & SPF"
	*Linear prediction, Dynamic 
	gen lin_dyn_`inflvar'_mispf = .

	forval i=`start_date'/`end_date' {
		forval j=1/5 {
			replace l`j'_`inflvar' = L`j'.lin_dyn_`inflvar'_mispf if quarter==`i' & L`j'.lin_dyn_`inflvar'_mispf!=. //refill lag variables to correspond to modeled inflation
		}
		predict temp_predict if quarter==`i' //get new modeled figure under appropriate lags
		replace lin_dyn_`inflvar'_mispf = temp_predict if quarter==`i' //stick datapoint in predicted variable under correct quarter
		//if `i'==`start_date'+6 stop
		drop temp_predict	
	}
	forval j=1/5 {
		replace l`j'_`inflvar' = l`j'_`inflvar'_copy //reset lag variables to correct values
	}	
	lab var lin_dyn_`inflvar'_mispf "Linear Model: MI & SPF"
	
	local F_lin_`inflvar'_mispf `=(e(rmse)^2)*e(df_r)' // cnsreg doesn't save e(rss)
	local obs_n_`inflvar'_mispf `=e(N)'
	scalar b_lin_mispf = _b[`threshvar']
	scalar SE_lin_mispf = _se[`threshvar']
	**************************************************************************************
	
	**Linear: SPF Only********************************************************************
		constraint drop _all
	// Constrain sum of inflation expectations to 1
	constraint 1 `expectations_2'
	
	if n_expvars > 1 {
		cnsreg `inflvar' `expvars_2' `pcsws_ctrls' `controls'  if fcastSamp, constraints(1)
	}
	else {
		reg `inflvar' `expvars_2' `pcsws_ctrls' `controls' if fcastSamp // reg still saves rmse & df_r in e()
	}
	

	
	*Linear prediction, 1 step ahead
	predict lin_1step_`inflvar'_spf_, xb
	lab var lin_1step_`inflvar'_spf_ "Linear Model: SPF"
	*Linear prediction, Dynamic 
	gen lin_dyn_`inflvar'_spf_ = .

	forval i=`start_date'/`end_date' {
		forval j=1/5 {
			replace l`j'_`inflvar' = L`j'.lin_dyn_`inflvar'_spf_ if quarter==`i' & L`j'.lin_dyn_`inflvar'_spf_!=. //refill lag variables to correspond to modeled inflation
		}
		predict temp_predict if quarter==`i' //get new modeled figure under appropriate lags
		replace lin_dyn_`inflvar'_spf_ = temp_predict if quarter==`i' //stick datapoint in predicted variable under correct quarter
		//if `i'==`start_date'+6 stop
		drop temp_predict	
	}
	forval j=1/5 {
		replace l`j'_`inflvar' = l`j'_`inflvar'_copy //reset lag variables to correct values
	}	
	lab var lin_dyn_`inflvar'_spf_ "Linear Model: SPF"
	
	local F_lin_`inflvar'_spf_ `=(e(rmse)^2)*e(df_r)' // cnsreg doesn't save e(rss)
	local obs_n_`inflvar'_spf_ `=e(N)'
	scalar b_lin_spf_ = _b[`threshvar']
	scalar SE_lin_spf_ = _se[`threshvar']
	**************************************************************************************************
	
	qui levelsof `threshvar' , local(u_local)
		
	
	* Setting bounds for threshold (this will be set for the rest of the file)
	qui sum `threshvar'  , detail 
	scalar thresh_`percentile' = r(p`percentile') 
	scalar thresh_`=100-`percentile'' = r(p`=100-`percentile'')
	scalar thresh_spread = floor((`percentile'/100)*e(N))
	
	constraint drop _all
	// Constrain sum of inflation expectations to 1
	constraint 1 `expectations'	
	
	* 2 distinct regime model
	// Create constant
	cap drop ones
	gen ones = 1 
	
	
	*With both MI and SPF
	local gamma_star_count 1
	foreach gamma_star in `u_local' {

			if (`gamma_star' >= thresh_`percentile') & (`gamma_star' <= thresh_`=100-`percentile'')  { //OB bounds for threshold values (adjustable by percentile)
			
				di "Counter ....."
				di `gamma_star_count'
				
				preserve

				
				gen left = .
				replace left = 1 if `threshvar'<=`gamma_star'
				replace left = 0 if mi(left)

				gen right = .
				replace right = 1 if !(`threshvar'<=`gamma_star')
				replace right = 0 if mi(right)
				
				constraint drop 2
				constraint 2 `gamma_star'*(`threshvar'_left-`threshvar'_right) + (ones_left-ones_right) = 0
				
				* create constant & urate (contemp & lagged diff) for each state
				gen ones_left = ones*left
				gen ones_right = ones*right
				
				local diffur_split
				
				foreach vv in `threshvar' `diffur' {
					gen `vv'_left = `vv'*left
					gen `vv'_right = `vv'*right
					if "`vv'"!="`threshvar'" { //for taking the mean 
						local diffur_split `diffur_split' `vv'_left `vv'_right	
					}		
				}
				
				*MI & SPF***************************************************************************************************
				constraint drop 1
				constraint 1 `expectations'
				
				cnsreg `inflvar' `expvars' *_left *_right `controls'  if fcastSamp,  constraints(1-2) nocons collinear
				
				// Minimization for cnsreg
				if ((e(rmse)^2)*e(df_r))<rm_`inflvar'_mispf { //cnsreg doesn't report e(rss), so it must be calculated as (root mean squared error)^2 * (residual degrees of freedom)
					//eststo minrss //save table for final output
					loc n_obs_2 = `=e(N)'
					scalar rm_`inflvar'_mispf =((e(rmse)^2)*e(df_r))
					noi di "2 Distinct Regimes, `inflvar' Sample: `sample', `gamma_star_count'"
					
					*Threshold prediction, 1 step ahead
					predict _1thr_1step_`inflvar'_mispf, xb
					lab var _1thr_1step_`inflvar'_mispf "Threshold Model: MI & SPF"
					
					*Linear prediction, Dynamic 
					gen _1thr_dyn_`inflvar'_mispf = .
					lab var _1thr_dyn_`inflvar'_mispf "Threshold Model: MI & SPF"
					forval i=`start_date'/`end_date' {
						forval j=1/5 {
							replace l`j'_`inflvar' = L`j'._1thr_dyn_`inflvar'_mispf if quarter==`i' & L`j'._1thr_dyn_`inflvar'_mispf!=. //refill lag variables to correspond to modeled inflation
						}
						predict temp_predict if quarter==`i' //get new modeled figure under appropriate lags
						replace _1thr_dyn_`inflvar'_mispf = temp_predict if quarter==`i' //stick datapoint in predicted variable under correct quarter
						//if `i'==`start_date'+6 stop
						drop temp_predict	
					}
					forval j=1/5 {
						replace l`j'_`inflvar' = l`j'_`inflvar'_copy  //reset lag variables to correct values
					}
					lab var _1thr_dyn_`inflvar'_mispf "Threshold Model: MI & SPF"
					tempfile pred_1thr_mispf 
					save `pred_1thr_mispf', replace					
				} 
				
				
				
				* SPF Only *******************************************************************************************************
				constraint drop 1
				constraint 1 `expectations_2'
				cnsreg `inflvar' `expvars_2' *_left *_right `controls' if fcastSamp,  constraints(1-2) nocons collinear
				
				// Collect slope estimates

			
				// Minimization for cnsreg
				if ((e(rmse)^2)*e(df_r))<rm_`inflvar'_spf_ { //cnsreg doesn't report e(rss), so it must be calculated as (root mean squared error)^2 * (residual degrees of freedom)
				
					*Threshold prediction, 1 step ahead
					predict _1thr_1step_`inflvar'_spf_, xb
					scalar rm_`inflvar'_spf_ = ((e(rmse)^2)*e(df_r))
					lab var _1thr_1step_`inflvar'_spf_ "Threshold Model: SPF" //"Threshold Model: SPF Only"
					*Linear prediction, Dynamic 
					gen _1thr_dyn_`inflvar'_spf_ = .
					forval i=`start_date'/`end_date' {
						forval j=1/5 {
							replace l`j'_`inflvar' = L`j'._1thr_dyn_`inflvar'_spf_ if quarter==`i' & L`j'._1thr_dyn_`inflvar'_spf_!=. //refill lag variables to correspond to modeled inflation
						}
						predict temp_predict if quarter==`i' //get new modeled figure under appropriate lags
						replace _1thr_dyn_`inflvar'_spf_ = temp_predict if quarter==`i' //stick datapoint in predicted variable under correct quarter
						drop temp_predict	
					}
					forval j=1/5 {
						replace l`j'_`inflvar' = l`j'_`inflvar'_copy  //reset lag variables to correct values
					}
					lab var _1thr_dyn_`inflvar'_spf_ "Threshold Model: SPF"
					tempfile pred_1thr_spf_ 
					save `pred_1thr_spf_', replace
				} 
				

				****************************************************************************************************
				****************************************************************************************************

				restore
			}
			
		local gamma_star_count `=`gamma_star_count'+1' //iteration counter	
	} //==> gamma_star loop
	drop *_copy

} // end output suppression

tempfile base_data
save `base_data', replace

use `pred_1thr_mispf', clear
keep quarter _1thr_1step_`inflvar'_mispf _1thr_dyn_`inflvar'_mispf
save `pred_1thr_mispf', replace

use `pred_1thr_spf_', clear
keep quarter _1thr_1step_`inflvar'_spf_ _1thr_dyn_`inflvar'_spf_
save `pred_1thr_spf-', replace

use `base_data', clear

merge 1:1 quarter using `pred_1thr_mispf', nogen
merge 1:1 quarter using `pred_1thr_spf_', nogen

*Calculate RRS for each measure 
gen residsq_1step_lin_mispf = (lin_1step_`inflvar'_mispf - `inflvar')^2
gen residsq_1step_mispf = (_1thr_1step_`inflvar'_mispf - `inflvar')^2
gen residsq_1step_spf_ = (_1thr_1step_`inflvar'_spf_ - `inflvar')^2
sum residsq_1step_lin_mispf if quarter>=`start_date' & quarter<=`end_date'
loc rss_1step_lin : di %4.1f r(sum)
sum residsq_1step_mispf if quarter>=`start_date' & quarter<=`end_date'
loc rss_1step_mispf : di %4.1f r(sum)
sum residsq_1step_spf_ if quarter>=`start_date' & quarter<=`end_date'
loc rss_1step_spf_  : di %4.1f r(sum)

gen residsq_dyn_lin_mispf = (lin_dyn_`inflvar'_mispf - `inflvar')^2
gen residsq_dyn_mispf = (_1thr_dyn_`inflvar'_mispf - `inflvar')^2
gen residsq_dyn_spf_ = (_1thr_dyn_`inflvar'_spf_ - `inflvar')^2
sum residsq_dyn_lin_mispf if quarter>=`start_date' & quarter<=`end_date'
loc rss_dyn_lin_mispf : di %4.1f r(sum)
sum residsq_dyn_mispf if quarter>=`start_date' & quarter<=`end_date'
loc rss_dyn_mispf : di %4.1f r(sum)
sum residsq_dyn_spf_ if quarter>=`start_date' & quarter<=`end_date'
loc rss_dyn_spf_ : di %4.1f r(sum)


gen fit_improve_1step = sqrt(residsq_1step_lin_mispf) - sqrt(residsq_1step_mispf)
gen fit_improve_dyn = sqrt(residsq_dyn_lin_mispf) - sqrt(residsq_dyn_mispf)
label var fit_improve_1step "Absolute Residual Improvement"
label var fit_improve_dyn "Absolute Residual Improvement"

* create deviations from inflation
foreach vv in lin_1step_`inflvar'_spf_ lin_1step_`inflvar'_mispf _1thr_1step_`inflvar'_spf_ _1thr_1step_`inflvar'_mispf {
	gen diff_`vv' = `vv'-`inflvar'
}


noi summ diff_lin_1step_`inflvar'_spf_ if quarter>=`start_date' & quarter<=`end_date'

if strmatch("`inflvar'", "*core*") {
	loc ystart 0
	loc yend 4
	loc legpos 2
	loc gmargin "small"	
	loc legopts "cols(1) size(large)"	
}
else if strmatch("`inflvar'", "infl_gdp") {
	loc ystart 2*round(r(min)/2) //-10
	loc yend 2*round(r(max)/2) //6
	loc legpos 12
	loc gmargin "medium"
	loc legopts "cols(2) size(medium)"	
}
else {
	loc ystart=2*round(r(min)/2) //-10
	loc yend=2*round(r(max)/2) //6
	loc legpos 2
	loc gmargin "small"	
	loc legopts "cols(1) size(large)"
}

foreach vv of var lin_1step_`inflvar'_spf_ lin_1step_`inflvar'_mispf _1thr_1step_`inflvar'_spf_ _1thr_1step_`inflvar'_mispf `inflvar' {
	
  tssmooth ma `vv'_ = `vv', window(3 1 0)
  replace `vv' = `vv'_
  
  replace `vv' = abs(`vv')
  //replace `vv' = . if quarter==tq(2008q4)

}

n di "`inflvar'"
n sum `inflvar'

tw line  lin_1step_`inflvar'_spf_ lin_1step_`inflvar'_mispf _1thr_1step_`inflvar'_spf_ _1thr_1step_`inflvar'_mispf `inflvar' quarter if quarter>=tq(2017q1) & quarter<=tq(2019q4), ///
yti("Inflation, %", size(large)) ysc(r(0,3.5)) ylab(0(.5)3.5, format(%3.1f) labsize(large) tp(i) angle(h) grid) ///
xti("") ///
xtick(`=yq(2017,1)-.5'(4)`=yq(2020,1)-.5', tp(i)) xlab(`=yq(2017,3)-.5' "2017" `=yq(2018,3)-.5' "2018" `=yq(2019,3)-.5' "2019" , labs(large) notick) xmti(`=yq(2017,1)-.5'(1)`=yq(2020,1)-.5', tp(i)) ///
legend(col(1) size(large) region(lw(none) color(none)) ring(0) position(6) ///
		  lab(1 "Linear model (lags, SPF)")  lab(2 "Linear model + UMSC") lab(3 "Threshold model (lags, SPF)") lab(4 "Threshold model (all)") lab(5 "CPI inflation") order(5 1 3 2 4)) /*order(1 2 3 4))*/  /// 
lc(red orange green blue black) lp(shortdash longdash_dot dash_dot solid solid) lw(0.5 .65 .5 0.65 .8 ) ///
scheme(s1color) plotregion(sty(none) margin(zero)) graphregion(margin(medsmall)) ///
yline(0, lc(black) lw(medthick))

graph display, ysize(2.5) xsize(3.25)	
graph export "../figures/figure2B.pdf", replace as(pdf) fontface("Georgia")
