***** compares estimated MI expectations to real MI in predicting inflation (also compares linear/threshold in the process).
***** F-stat p-values are obtained by bootstrapping
***** Order of args: inflation, threshold var, piecewise, exp & other controls, sample


args inflvar threshvar pcsws_ctrls controls expvars expvars_2 start_date
set matsize 11000

local percentile 10

sum quarter
local end_date  `=r(max)' 

*Create windows for pre-Volcker inflation, Volcker disinflation, post-Recession
local period_1_beg `=q(1976q2)' //Inflationary period, late '70s
local period_1_end `=q(1980q1)'
local period_2_beg `=q(1980q1)' //Volcker Disinflation
local period_2_end `=q(1983q1)'
local period_3_beg `=q(2009q1)' //Inflationary period, late '70s
local period_3_end `=q(2013q4)'

local length_period_1 `=`period_1_end' - `period_1_beg''
local length_period_2 `=`period_2_end' - `period_2_beg''
local length_period_3 `=`period_3_end' - `period_3_beg''


*Define peaks and troughs for inflation during Volcker era based on CPI inflation
su `inflvar' if quarter >=`period_1_beg' & quarter <=`period_2_end'
su quarter if `inflvar'==r(max) & quarter >=`period_1_beg' & quarter <=`period_2_end' //peak
local period_peak `period_1_end' // `=r(max)'

*Period 1 trough
//su `inflvar' if quarter >=`period_1_beg' & quarter <=`period_peak'
//su quarter if `inflvar'==r(min) & quarter >=`period_1_beg' & quarter <=`period_peak' //trough 1
local period_1_trough `period_1_beg' // `=r(max)'
local length_peak_to_trough_1 `=`period_peak' - `period_1_trough''
di `length_peak_to_trough_1'

*Period 2 trough
//su `inflvar' if quarter >=`period_peak' & quarter <=`period_2_end'
//su quarter if `inflvar'==r(min) & quarter >=`period_peak' & quarter <=`period_2_end' //trough 2
local period_2_trough `=q(1983q1)' //`=r(min)'
local length_peak_to_trough_2 `=`period_2_trough' - `period_peak''
di `length_peak_to_trough_2'

if "`inflvar'"=="infl_pce_core" {
	label var infl_pce_core "PCE Core infl. (SAAR, %)"	
}
else if "`inflvar'"=="infl_pce" {
	label var infl_pce "PCE infl. (SAAR, %)"	
}	
* restrict dataset to regression sample
qui reg `inflvar' `expvars' `pcsws_ctrls' `controls'
gen tempsample = e(sample)
keep if tempsample == 1
drop tempsample

* In case we decide to include difference of urate in regression, then it needs to be averaged for graph
if "`threshvar'"!="`pcsws_ctrls'" {
	if "`inflvar'"=="infl_gdp" {
		qui ds l1_d_u_rate - l4_d_u_rate
		local diffur "`r(varlist)'"
	}	
	else {
		qui ds l0_d_u_rate - l2_d_u_rate
		local diffur "`r(varlist)'"	
	}
}

else {
	local diffur //otherwise leave blank
}	

if "`threshvar' `diffur'"!= "`pcsws_ctrls'"  {
	if "`threshvar' `diffur'"!= "`pcsws_ctrls' " { //extra space might throw Stata off (coming from empty local)
		di "`threshvar'" "`diffur'"
		di "`pcsws_ctrls'"
		di ("`threshvar'`diffur'"=="`pcsws_ctrls'")
		di "Error in pcsws_ctrls specification"
		stop //to catch mistake in code
	}
}		

* Create expecatations constraint
qui ds `expvars'
scalar n_expvars = `=wordcount("`r(varlist)'")'
if n_expvars > 1 { // if more than 1 inflation expectations term
	loc expectations `=subinstr("`r(varlist)'"," ","+",.)' = 1
}	

qui ds `expvars_2'
scalar n_expvars_2 = `=wordcount("`r(varlist)'")'
if n_expvars_2 > 1 { // if more than 1 inflation expectations term
	loc expectations_2 `=subinstr("`r(varlist)'"," ","+",.)' = 1
}	

/* //check if the args passed successfully 
di "`inflvar'"
di "`threshvar'"
di "`pcsws_ctrls'"
di "`controls'"
di "`expectations'"
di "`sample'"
di "`boot'" 
di "`LR'"  
*/

cap log close
forval lag = 1/5 {
	gen l`lag'_`inflvar'_copy = l`lag'_`inflvar' //preserve lag copy to restore once we tweak it for dynamic model
}

* Estimate 1--with both MI and SPF - 
qui { // Display only counter & results
	* initialize SSR & gamma scalars for 2 -regime grid search
	scalar rm_`inflvar'_mispf = 100000
	scalar rm_`inflvar'_mihat = 100000
	scalar gstar_`inflvar'_2 = -666
	
*** With MI actuals
	constraint drop _all
	// Constrain sum of inflation expectations to 1
	constraint 1 `expectations'
	
	if n_expvars > 1 {
		cnsreg `inflvar' `expvars' `pcsws_ctrls' `controls'  , constraints(1)
	}
	else {
		reg `inflvar' `expvars' `pcsws_ctrls' `controls' // reg still saves rmse & df_r in e()
	}
	
	*Linear prediction, 1 step ahead
	predict lin_1step_`inflvar'_mispf, xb
	lab var lin_1step_`inflvar'_mispf "Linear Model; MI actual"
	
	*Linear prediction, Dynamic 
	gen lin_dyn_`inflvar'_mispf = .
	
	forval i=`start_date'/`end_date' {
		forval j=1/5 {
			replace l`j'_`inflvar' = L`j'.lin_dyn_`inflvar'_mispf if quarter==`i' & L`j'.lin_dyn_`inflvar'_mispf !=. //refill lag variables to correspond to modeled inflation
		}
		predict temp_predict if quarter==`i' //get new modeled figure under appropriate lags
		replace lin_dyn_`inflvar'_mispf = temp_predict if quarter==`i' //stick datapoint in predicted variable under correct quarter
		//if `i'==`start_date'+6 stop
		drop temp_predict	
	}
	
	forval j=1/5 {
		replace l`j'_`inflvar' = l`j'_`inflvar'_copy //reset lag variables to correct values
	}	
	lab var lin_dyn_`inflvar'_mispf "Linear Model; MI actual"

*** With MI fitted values
	constraint drop _all
	// Constrain sum of inflation expectations to 1
	constraint 1 `expectations_2'
	
	if n_expvars_2 > 1 {
		cnsreg `inflvar' `expvars_2' `pcsws_ctrls' `controls'  , constraints(1)
	}
	else {
		reg `inflvar' `expvars_2' `pcsws_ctrls' `controls' // reg still saves rmse & df_r in e()
	}
	
	*Linear prediction, 1 step ahead
	predict lin_1step_`inflvar'_mihat, xb
	lab var lin_1step_`inflvar'_mihat "Linear Model; MI_hat"
	
	*Linear prediction, Dynamic 
	gen lin_dyn_`inflvar'_mihat = .

	forval i=`start_date'/`end_date' {
		forval j=1/5 {
			replace l`j'_`inflvar' = L`j'.lin_dyn_`inflvar'_mihat if quarter==`i' & L`j'.lin_dyn_`inflvar'_mihat !=. //refill lag variables to correspond to modeled inflation
		}
		predict temp_predict if quarter==`i' //get new modeled figure under appropriate lags
		replace lin_dyn_`inflvar'_mihat = temp_predict if quarter==`i' //stick datapoint in predicted variable under correct quarter
		//if `i'==`start_date'+6 stop
		drop temp_predict	
	}
	
	forval j=1/5 {
		replace l`j'_`inflvar' = l`j'_`inflvar'_copy //reset lag variables to correct values
	}	
	lab var lin_dyn_`inflvar'_mihat "Linear Model; MI_hat"

	
	qui levelsof `threshvar' , local(u_local)
		
	
	* Setting bounds for threshold (this will be set for the rest of the file)
	qui sum `threshvar'  , detail 
	scalar thresh_`percentile' = r(p`percentile') 
	scalar thresh_`=100-`percentile'' = r(p`=100-`percentile'')
	scalar thresh_spread = floor((`percentile'/100)*e(N))
	
/*	constraint drop _all
	// Constrain sum of inflation expectations to 1
	constraint 1 `expectations'	
*/
	
	* 2 distinct regime model
	// Create constant
	cap drop ones
	gen ones = 1 
	
	
	*With both MI and SPF
	local gamma_star_count 1
	foreach gamma_star in `u_local' {

			if (`gamma_star' >= thresh_`percentile') & (`gamma_star' <= thresh_`=100-`percentile'')  { //OB bounds for threshold values (adjustable by percentile)

				di "Counter ....."
				di `gamma_star_count'
				
				preserve

				
				gen left = .
				replace left = 1 if `threshvar'<=`gamma_star'
				replace left = 0 if mi(left)

				gen right = .
				replace right = 1 if !(`threshvar'<=`gamma_star')
				replace right = 0 if mi(right)
				
				constraint drop 2
				constraint 2 `gamma_star'*(`threshvar'_left-`threshvar'_right) + (ones_left-ones_right) = 0
				
				* create constant & urate (contemp & lagged diff) for each state
				gen ones_left = ones*left
				gen ones_right = ones*right
				
				local diffur_split
				
				foreach vv in `threshvar' `diffur' {
					gen `vv'_left = `vv'*left
					gen `vv'_right = `vv'*right
					if "`vv'"!="`threshvar'" { //for taking the mean 
						local diffur_split `diffur_split' `vv'_left `vv'_right	
					}		
				}
				
				* SPF & MI actual    ***************************************************************************************************
				constraint drop 1
				constraint 1 `expectations'
				
				cnsreg `inflvar' `expvars' *_left *_right `controls'  ,  constraints(1-2) nocons collinear
				
				// Minimization for cnsreg
				if ((e(rmse)^2)*e(df_r))<rm_`inflvar'_mispf { //cnsreg doesn't report e(rss), so it must be calculated as (root mean squared error)^2 * (residual degrees of freedom)
					//eststo minrss //save table for final output
					loc n_obs_2 = `=e(N)'
					scalar rm_`inflvar'_mispf =((e(rmse)^2)*e(df_r))
					noi di "2 Distinct Regimes, `inflvar' Sample: `sample', `gamma_star_count'"
					
					*Threshold prediction, 1 step ahead
					predict _1thr_1step_`inflvar'_mispf, xb
					lab var _1thr_1step_`inflvar'_mispf "Threshold Model"
					
					*Linear prediction, Dynamic 
					gen _1thr_dyn_`inflvar'_mispf = .
					lab var _1thr_dyn_`inflvar'_mispf "Threshold; w/ actual MI"
					forval i=`start_date'/`end_date' {
						forval j=1/5 {
							replace l`j'_`inflvar' = L`j'._1thr_dyn_`inflvar'_mispf if quarter==`i' & L`j'._1thr_dyn_`inflvar'_mispf!=. //refill lag variables to correspond to modeled inflation
						}
						predict temp_predict if quarter==`i' //get new modeled figure under appropriate lags
						replace _1thr_dyn_`inflvar'_mispf = temp_predict if quarter==`i' //stick datapoint in predicted variable under correct quarter
						//if `i'==`start_date'+6 stop
						drop temp_predict	
					}
					forval j=1/5 {
						replace l`j'_`inflvar' = l`j'_`inflvar'_copy  //reset lag variables to correct values
					}
					lab var _1thr_dyn_`inflvar'_mispf "Threshold; w/ actual MI"
					tempfile pred_1thr_mispf 
					save `pred_1thr_mispf', replace					
				} 
				
	
				
				* SPF and est MI *******************************************************************************************************
				constraint drop 1
				constraint 1 `expectations_2'
				cnsreg `inflvar' `expvars_2' *_left *_right `controls'  ,  constraints(1-2) nocons collinear
				
				// Collect slope estimates

			
				// Minimization for cnsreg
				if ((e(rmse)^2)*e(df_r))<rm_`inflvar'_mihat { //cnsreg doesn't report e(rss), so it must be calculated as (root mean squared error)^2 * (residual degrees of freedom)
				
					*Threshold prediction, 1 step ahead
					predict _1thr_1step_`inflvar'_mihat, xb
					scalar rm_`inflvar'_mihat = ((e(rmse)^2)*e(df_r))
					lab var _1thr_1step_`inflvar'_mihat "Threshold; w/ MI_hat"
					*Linear prediction, Dynamic 
					gen _1thr_dyn_`inflvar'_mihat = .

					forval i=`start_date'/`end_date' {
						forval j=1/5 {
							replace l`j'_`inflvar' = L`j'._1thr_dyn_`inflvar'_mihat if quarter==`i' & L`j'._1thr_dyn_`inflvar'_mihat!=. //refill lag variables to correspond to modeled inflation
						}
						predict temp_predict if quarter==`i' //get new modeled figure under appropriate lags
						replace _1thr_dyn_`inflvar'_mihat = temp_predict if quarter==`i' //stick datapoint in predicted variable under correct quarter
						drop temp_predict	
					}
					forval j=1/5 {
						replace l`j'_`inflvar' = l`j'_`inflvar'_copy  //reset lag variables to correct values
					}

					lab var _1thr_dyn_`inflvar'_mihat "Threshold; w/ MI_hat"
					tempfile pred_1thr_mihat 
					save `pred_1thr_mihat', replace
				} 
				
				

				****************************************************************************************************
				****************************************************************************************************

				restore
			}
			
		local gamma_star_count `=`gamma_star_count'+1' //iteration counter	
	} //==> gamma_star loop
	drop *_copy

} // end output suppression

tempfile base_data
save `base_data', replace

use `pred_1thr_mispf', clear
keep quarter _1thr_1step_`inflvar'_mispf _1thr_dyn_`inflvar'_mispf
save `pred_1thr_mispf', replace

use `pred_1thr_mihat', clear
keep quarter _1thr_1step_`inflvar'_mihat _1thr_dyn_`inflvar'_mihat 
save `pred_1thr_mihat', replace
use `base_data', clear

merge 1:1 quarter using `pred_1thr_mispf', nogen
merge 1:1 quarter using `pred_1thr_mihat', nogen
/*
*Calculate RRS for each measure 
gen residsq_1step_lin = (lin_1step_`inflvar' - `inflvar')^2
gen residsq_1step_mispf = (_1thr_1step_`inflvar'_mispf - `inflvar')^2
gen residsq_1step_mihat = (_1thr_1step_`inflvar'_mihat - `inflvar')^2
sum residsq_1step_lin if quarter>=`start_date' & quarter<=`end_date'
loc rss_1step_lin : di %4.1f r(sum)
sum residsq_1step_mispf if quarter>=`start_date' & quarter<=`end_date'
loc rss_1step_mispf : di %4.1f r(sum)
sum residsq_1step_mihat if quarter>=`start_date' & quarter<=`end_date'
loc rss_1step_mihat  : di %4.1f r(sum)
*/

gen residsq_lin_dyn_mispf = (lin_dyn_`inflvar'_mispf - `inflvar')^2
gen residsq_lin_dyn_mihat = (lin_dyn_`inflvar'_mihat - `inflvar')^2
gen residsq_dyn_mispf = (_1thr_dyn_`inflvar'_mispf - `inflvar')^2
gen residsq_dyn_mihat = (_1thr_dyn_`inflvar'_mihat - `inflvar')^2
/*
sum residsq_dyn_lin if quarter>=`start_date' & quarter<=`end_date'
loc rss_dyn_lin : di %4.1f r(sum)
sum residsq_dyn_mispf if quarter>=`start_date' & quarter<=`end_date'
loc rss_dyn_mispf : di %4.1f r(sum)
sum residsq_dyn_mihat if quarter>=`start_date' & quarter<=`end_date'
loc rss_dyn_mihat : di %4.1f r(sum)
*/
/*
gen fit_improve_1step = sqrt(residsq_1step_lin) - sqrt(residsq_1step_mispf)
gen fit_improve_dyn = sqrt(residsq_dyn_lin) - sqrt(residsq_dyn_mispf)
label var fit_improve_1step "Absolute Residual Improvement"
label var fit_improve_dyn "Absolute Residual Improvement"


tw line `inflvar' lin_1step_`inflvar' _1thr_1step_`inflvar'_mispf quarter if quarter>=`start_date' & quarter<=`end_date', yti("Inflation") name(_1step_pred) legend(rows(3) ring(0) position(2)) /// //, caption("Lin: "`=round(rss_1step_lin, 0.1)' "MI SPF : "`=round(rss_1step_mispf, 0.1)', span)
	scheme(s1color) plotregion(sty(none) margin(zero))   graphregion(margin(medium))    

tw bar fit_improve_1step quarter if quarter>=`start_date' & quarter<=`end_date', ylab(-.4(.2).4) name(_1step_bar) /// // added ylab for recession sample
	scheme(s1color) plotregion(sty(none) margin(zero))   graphregion(margin(medium))
graph combine _1step_pred _1step_bar , subtitle("Linear RSS: `rss_1step_lin', Threshold RSS: `rss_1step_mispf'") rows(2) scheme(s1color) plotregion(sty(none) margin(zero))   graphregion(margin(medium))
*graph export "../Figures/Inflation Predictions/Memo/Base Case/Full Sample/1step_`inflvar'_`threshvar'_`sample_count'.png", replace width(3200)
graph export "../Figures/Inflation Predictions/Memo/Full Sample/1step_`inflvar'_`threshvar'_`sample_count'.png", replace width(3200)
graph export "../Figures/Inflation Predictions/Memo/Full Sample/dyn_`inflvar'_`threshvar'_`sample_count'.pdf", replace 
*/
gen test = abs(lin_dyn_`inflvar'_mispf - lin_1step_`inflvar'_mispf)


ds `inflvar' *_dyn_`inflvar'*

foreach vv in `r(varlist)' {
	gen chg_`vv' = `vv' - L`length_peak_to_trough_1'.`vv' if quarter==`period_peak'
	replace chg_`vv' = `vv' - L`length_peak_to_trough_2'.`vv' if quarter==`period_2_trough'
	//replace chg_`vv' = `vv' - L`length_period_3'.`vv' if quarter==`period_3_end'
}

format chg_* `inflvar' *_dyn_* %3.1f

di "Series considered: `inflvar'"
li quarter `inflvar' lin_dyn_`inflvar'_mispf lin_dyn_`inflvar'_mihat _1thr_dyn_`inflvar'_mispf _1thr_dyn_`inflvar'_mihat if inlist(quarter, q(1976q2), q(1976q4), q(1979q2), q(1979q4),q(1980q1), q(1983q1), q(1985q4))
ds quarter chg_*
li quarter chg_* if inlist(quarter,`period_peak', `period_2_trough')

* Save peak-trough diff for great inflation and volcker disinfl
ds chg_*
foreach vv in `r(varlist)' {
	summ `vv' if inlist(quarter,`period_peak')
	scalar d1_`vv' = r(max)
	di d1_`vv'
	
	summ `vv' if inlist(quarter,`period_2_trough')
	scalar d2_`vv' = r(max)
	di d2_`vv'	
}


ds residsq*
foreach residvar in `r(varlist)' {
	di ""
	di "Variable: `residvar'"
	qui sum `residvar' if quarter>=`period_1_beg' & quarter<=`period_1_end'
	scalar rmse1_`residvar' = sqrt(r(mean))
	di "Inflation Period: " %4.2f sqrt(r(mean))
	
	qui sum `residvar' if quarter>=`period_2_beg' & quarter<=`period_2_end'
	di "Disinflation Period: " %4.2f sqrt(r(mean))	
	scalar rmse2_`residvar' = sqrt(r(mean))
	
	qui sum `residvar' if quarter>=`period_3_beg' & quarter<=`period_3_end'
	di "Post-recession: " %4.2f sqrt(r(mean))	
	scalar rmse3_`residvar' = sqrt(r(mean))
}

* create deviations from inflation
foreach vv in lin_dyn_`inflvar'_mispf lin_dyn_`inflvar'_mihat _1thr_dyn_`inflvar'_mispf _1thr_dyn_`inflvar'_mihat {
	gen diff_`vv' = `vv'-`inflvar'
}


// subsample
if `start_date' < `=tq(1985q1)' { // create subsample graphs for volcker era
* define locals for y axis bounds
 if `start_date' == `=tq(1976q2)' {
	loc subend `=tq(1979q4)'
 }
 else if `start_date' == `=tq(1976q2)' {
	loc subend `=tq(1979q4)'
 }
 else {
	loc subend `=tq(1985q4)'
 }

	noi summ `inflvar' if quarter>=`start_date' & quarter<=`subend'
	
	loc legopts "cols(1)" // default
	
	if strmatch("`inflvar'","infl_gdp") {
		#delimit ;
		loc ystart1 2; loc yend1 14; loc legpos1 2; loc legopts1 "cols(2) r(3) size(medsmall) colg(*-0.55) keyg(*-1)";
		loc ystart2 =2*round(r(min)/2); loc yend2 =2*round(r(max)/2); loc legpos2 11; loc legopts2 "cols(1) size(medium)"; loc gmargin "small";
		loc ystart3 =2*round(r(min)/2); loc yend3 =2*round(r(max)/2); loc legpos3 2; loc legopts3 "cols(1) size(medium)";
		#delimit cr	
	}
	else if strmatch("`inflvar'","infl_cpi") {
		#delimit ;
		loc ystart1 -2; loc yend1 4; loc legpos1 11; loc legopts1 "cols(1) size(medlarge)";
		loc ystart2 -2; loc yend2 4; loc legpos2 11; loc legopts2 "cols(1) size(large)"; loc gmargin "medium";
		loc ystart3 -4; loc yend3 6; loc legpos3 1; loc legopts3 "cols(1) size(large)";
		#delimit cr
	}
	else if strmatch("`inflvar'","infl_pce") {
		#delimit ;
		loc ystart1 2; loc yend1 14; loc legpos1 2; loc legopts1 "cols(2) r(3) size(medsmall) colg(*3)";
		loc ystart2 =2*round(r(min)/2); loc yend2 =2*round(r(max)/2); loc legpos2 11; loc legopts2 "cols(1) size(medium)"; loc gmargin "small";
		loc ystart3 =2*round(r(min)/2); loc yend3 =2*round(r(max)/2); loc legpos3 2; loc legopts3 "cols(1) size(medium)";
		#delimit cr		
	}	
	
foreach vv of var diff_lin_dyn_`inflvar'_mispf diff_lin_dyn_`inflvar'_mihat diff__1thr_dyn_`inflvar'_mispf diff__1thr_dyn_`inflvar'_mihat {
	
  tssmooth ma `vv'_ = `vv', window(3 1 0)
  *replace `vv' = `vv'_
  
  replace `vv' = abs(`vv')
  //replace `vv' = . if quarter==tq(2008q4)
  

}


}

//graph close
//graph drop _all

